// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('wilger', ['ionic', 'ngIOS9UIWebViewPatch', 'wilger.controllers', 'wilger.services'])

.run(function($ionicPlatform) {
    $ionicPlatform.ready(function() {
        // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
        // for form inputs)
        if (window.cordova && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
        }
        if (window.StatusBar) {
            // org.apache.cordova.statusbar required
            StatusBar.styleDefault();
        }
    });
})

.directive('ionRadioFix', function() {
  return {
    restrict: 'E',
    replace: true,
    require: '?ngModel',
    transclude: true,
    template:
      '<label class="item item-radio">' +
        '<input type="radio" name="radio-group">' +
        '<div class="radio-content">' +
          '<div class="item-content disable-pointer-events" ng-transclude></div>' +
          '<i class="radio-icon disable-pointer-events icon ion-checkmark"></i>' +
        '</div>' +
      '</label>',

    compile: function(element, attr) {
      if (attr.icon) {
        var iconElm = element.find('i');
        iconElm.removeClass('ion-checkmark').addClass(attr.icon);
      }

      var input = element.find('input');
      angular.forEach({
          'name': attr.name,
          'value': attr.value,
          'disabled': attr.disabled,
          'ng-value': attr.ngValue,
          'ng-model': attr.ngModel,
          'ng-disabled': attr.ngDisabled,
          'ng-change': attr.ngChange,
          'ng-required': attr.ngRequired,
          'required': attr.required
      }, function(value, name) {
        if (angular.isDefined(value)) {
            input.attr(name, value);
          }
      });

      return function(scope, element, attr) {
        scope.getValue = function() {
          return scope.ngValue || attr.value;
        };
      };
    }
  };
})

.config(function($stateProvider, $urlRouterProvider, $ionicConfigProvider) {

    $ionicConfigProvider.backButton.text('Back').icon('ion-ios-arrow-left').previousTitleText(false);

    // Ionic uses AngularUI Router which uses the concept of states
    // Learn more here: https://github.com/angular-ui/ui-router
    // Set up the various states which the app can be in.
    // Each state's controller can be found in controllers.js
    $stateProvider

    // setup an abstract state for the tabs directive
    .state('tab', {
        url: '/tab',
        abstract: true,
        templateUrl: 'templates/tabs.html'
    })

    // Each tab has its own nav history stack:

    .state('tab.wizard', {
        url: '/wizard',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard.html',
                controller: 'WizardMainCtrl'
            }
        }
    })

    .state('tab.calc-standard', {
        url: '/calc-standard',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-calc-standard.html',
                controller: 'WizardCalcStandardCtrl'
            }
        }
    })

    .state('tab.calc-pulsed', {
        url: '/calc-pulsed',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-calc-pulsed.html',
                controller: 'WizardCalcPulsedCtrl'
            }
        }
    })

    .state('tab.calc-pulsed-results', {
        url: '/calc-pulsed-results',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-calc-pulsed-results.html',
                controller: 'WizardCalcPulsedResultsCtrl'
            }
        }
    })

    .state('tab.calc-standard-results', {
        url: '/calc-standard-results',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-calc-standard-results.html',
                controller: 'WizardCalcStandardResultsCtrl'
            }
        }
    })

    .state('tab.specific-standard', {
        url: '/specific-standard',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-specific-standard.html',
                controller: 'WizardSpecificStandardCtrl'
            }
        }
    })

    .state('tab.specific-pulsed', {
        url: '/specific-pulsed',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-specific-pulsed.html',
                controller: 'WizardSpecificPulsedCtrl'
            }
        }
    })

    .state('tab.specific-standard-results', {
        url: '/specific-standard-results',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-specific-standard-results.html',
                controller: 'WizardSpecificStandardResultsCtrl'
            }
        }
    })

    .state('tab.specific-pulsed-results', {
        url: '/specific-pulsed-results',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-specific-pulsed-results.html',
                controller: 'WizardSpecificPulsedResultsCtrl'
            }
        }
    })

    .state('tab.favorites-standard', {
        url: '/favorites-standard',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-favorites-standard.html',
                controller: 'WizardFavoritesStandardCtrl'
            }
        }
    })

    .state('tab.favorites-pulsed', {
        url: '/favorites-pulsed',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-favorites-pulsed.html',
                controller: 'WizardFavoritesPulsedCtrl'
            }
        }
    })

    .state('tab.favorites-standard-results', {
        url: '/favorites-standard-results',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-favorites-standard-results.html',
                controller: 'WizardFavoritesStandardResultsCtrl'
            }
        }
    })

    .state('tab.favorites-pulsed-results', {
        url: '/favorites-pulsed-results',
        views: {
            'tab-wizard': {
                templateUrl: 'templates/tab-wizard-favorites-pulsed-results.html',
                controller: 'WizardFavoritesPulsedResultsCtrl'
            }
        }
    })

    // .state('tab.favorites', {
    //     url: '/favorites',
    //     views: {
    //         'tab-favorites': {
    //             templateUrl: 'templates/tab-favorites.html',
    //             controller: 'FavoritesCtrl'
    //         }
    //     }
    // })

    .state('tab.fertilizer', {
        url: '/fertilizer',
        views: {
            'tab-fertilizer': {
                templateUrl: 'templates/tab-fertilizer.html',
                controller: 'FertilizerCtrl'
            }
        }
    })

    .state('tab.fertilizer-results', {
        url: '/fertilizer-results',
        views: {
            'tab-fertilizer': {
                templateUrl: 'templates/tab-fertilizer-results.html',
                controller: 'FertilizerResultsCtrl'
            }
        }
    })

    .state('tab.contact', {
        url: '/contact',
        views: {
            'tab-contact': {
                templateUrl: 'templates/tab-contact.html',
                controller: 'ContactCtrl'
            }
        }
    });

    // if none of the above states are matched, use this as the fallback
    $urlRouterProvider.otherwise('/tab/wizard');

});
