
SORT_ORDER = {
    "ER": 1,
    "SR": 2,
    "MR": 3,
    "DR": 4
};

var array_unique = function(a) {
    return a.reduce(function(p, c) {
        if (p.indexOf(c) < 0) p.push(c);
        return p;
    }, []);
};

function sort_tips (filtered) {
    return filtered.sort(function (ela, elb) {
        var ela_style = SORT_ORDER[ela["tip"].substring(0,2)];
        var ela_size = ela["tip"].substring(2);

        var elb_style = SORT_ORDER[elb["tip"].substring(0,2)];
        var elb_size = elb["tip"].substring(2);

        // Sort by tip
        if (ela_size < elb_size) {
            return -1;
        } else if (ela_size > elb_size) {
            return 1;
        } else {

            // If tip is the same sort by style
            if (ela_style < elb_style) {
                return -1;
            } else if (ela_style < elb_style) {
                return 1;
            } else {
                return 0;
            }

        }
    });

}

function sort_fertilizer_tips (filtered) {
    return filtered.sort(function (ela, elb) {
        ela_size = parseFloat(ela["tip"].substring(1));
        elb_size = parseFloat(elb["tip"].substring(1));

        // Sort by tip
        if (ela_size < elb_size) {
            return -1;
        } else if (ela_size > elb_size) {
            return 1;
        }
    });
}

function format_number (n) {

    if (n >= 100.0) {
        return n.toFixed(0);
    } else if (n >= 10.0) {
        return n.toFixed(1);
    } else {
        return n.toFixed(2);
    }

}

var tips_table = [
    {
        "ang": "80",
        "tip": "ER80-005",
        "part_no": "40270-005",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "0.05",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.008",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.035",
        "r_max": "0.071",
        "vmd_s": "403.43*Math.pow(pt,-0.2936)",
        "141_s": "31.95*Math.log(pt)-62.469",
        "200_s": "Math.min(24.528*Math.log(pt)-5.887,100)",
        "600_s": "100.0",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.008",
        "orf_eff": "0.05",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.001",
        "p_max": "65",
        "r_min_b": "0.009",
        "r_max_b": "0.064",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "403.43*Math.pow(pt_b,-0.2936)",
        "141_b": "31.95*Math.log(pt_b)-62.469",
        "200_b": "Math.min(24.528*Math.log(pt_b)-5.887,100)",
        "600_b": "100.0",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "ER80-0067",
        "part_no": "40270-007",
        "color": "Pink", "csscolor": "tip-pink",
        "tip_rate": "0.067",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.011",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.047",
        "r_max": "0.095",
        "vmd_s": "619.31*Math.pow(pt,-0.3785)",
        "141_s": "33.413*Math.log(pt)-78.661",
        "200_s": "Math.min(34.074*Math.log(pt)-50.894,100)",
        "600_s": "100",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.011",
        "orf_eff": "0.07",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.002",
        "p_max": "65",
        "r_min_b": "0.012",
        "r_max_b": "0.085",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "619.31*Math.pow(pt_b,-0.3785)",
        "141_b": "33.413*Math.log(pt_b)-78.661",
        "200_b": "Math.min(34.074*Math.log(pt_b)-50.894,100)",
        "600_b": "100",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "ER80-01",
        "part_no": "40270-01",
        "color": "Orange", "csscolor": "tip-orange",
        "tip_rate": "0.1",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.016",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.071",
        "r_max": "0.141",
        "vmd_s": "418.37*Math.pow(pt,-0.2901)",
        "141_s": "30.096*Math.log(pt)-61.612",
        "200_s": "Math.min(24.521*Math.log(pt)-9.3599,100)",
        "600_s": "100",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.016",
        "orf_eff": "0.10",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.004",
        "p_max": "65",
        "r_min_b": "0.018",
        "r_max_b": "0.127",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "418.37*Math.pow(pt_b,-0.2901)",
        "141_b": "30.096*Math.log(pt_b)-61.612",
        "200_b": "Math.min(24.521*Math.log(pt_b)-9.3599,100)",
        "600_b": "100",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "ER80-015",
        "part_no": "40270-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate": "0.15",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.024",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.106",
        "r_max": "0.212",
        "vmd_s": "425.96*Math.pow(pt,-0.2539)",
        "141_s": "19.82*Math.log(pt)-38.678",
        "200_s": "21.165*Math.log(pt)-13.022",
        "600_s": "100.0",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.024",
        "orf_eff": "0.15",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.009",
        "p_max": "64",
        "r_min_b": "0.026",
        "r_max_b": "0.190",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "425.96*Math.pow(pt_b,-0.2539)",
        "141_b": "19.82*Math.log(pt_b)-38.678",
        "200_b": "21.165*Math.log(pt_b)-13.022",
        "600_b": "100.0",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "ER80-02",
        "part_no": "40270-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate": "0.2",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.032",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.141",
        "r_max": "0.283",
        "vmd_s": "324.48*Math.pow(pt,-0.1892)",
        "141_s": "15.111*Math.log(pt)-17.348",
        "200_s": "14.01*Math.log(pt)+14.74",
        "600_s": "100-0.0106*pt-0.179",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.031",
        "orf_eff": "0.20",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.017",
        "p_max": "64",
        "r_min_b": "0.035",
        "r_max_b": "0.253",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "324.48*Math.pow(pt_b,-0.1892)",
        "141_b": "15.111*Math.log(pt_b)-17.348",
        "200_b": "14.01*Math.log(pt_b)+14.74",
        "600_b": "100-0.0106*pt_b-0.179",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "ER80-025",
        "part_no": "40270-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate": "0.25",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.040",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.177",
        "r_max": "0.354",
        "vmd_s": "510.39*Math.pow(pt,-0.2629)",
        "141_s": "15.706*Math.log(pt)-29.943",
        "200_s": "19.419*Math.log(pt)-20.349",
        "600_s": "100-0.1413*Math.pow(pt,(0.2945))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.039",
        "orf_eff": "0.25",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.026",
        "p_max": "63",
        "r_min_b": "0.044",
        "r_max_b": "0.315",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "510.39*Math.pow(pt_b,-0.2629)",
        "141_b": "15.706*Math.log(pt_b)-29.943",
        "200_b": "19.419*Math.log(pt_b)-20.349",
        "600_b": "100-0.1413*Math.pow(pt_b,(0.2945))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "ER80-03",
        "part_no": "40270-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate": "0.3",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.047",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.212",
        "r_max": "0.424",
        "vmd_s": "439.46*Math.pow(pt,-0.212)",
        "141_s": "13.002*Math.log(pt)-21.67",
        "200_s": "15.694*Math.log(pt)-8.7893",
        "600_s": "100-0.4372*Math.pow(pt,(0.1589))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.047",
        "orf_eff": "0.29",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.037",
        "p_max": "63",
        "r_min_b": "0.052",
        "r_max_b": "0.375",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "439.46*Math.pow(pt_b,-0.212)",
        "141_b": "13.002*Math.log(pt_b)-21.67",
        "200_b": "15.694*Math.log(pt_b)-8.7893",
        "600_b": "100-0.4372*Math.pow(pt_b,(0.1589))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "ER80-04",
        "part_no": "40270-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate": "0.4",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.063",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.283",
        "r_max": "0.566",
        "vmd_s": "476.16*Math.pow(pt,-0.214)",
        "141_s": "10.409*Math.log(pt)-14.732",
        "200_s": "14.859*Math.log(pt)-10.326",
        "600_s": "100-1.9313*Math.pow(pt,(-0.2355))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.061",
        "orf_eff": "0.39",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.067",
        "p_max": "61",
        "r_min_b": "0.068",
        "r_max_b": "0.494",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "476.16*Math.pow(pt_b,-0.214)",
        "141_b": "10.409*Math.log(pt_b)-14.732",
        "200_b": "14.859*Math.log(pt_b)-10.326",
        "600_b": "100-1.9313*Math.pow(pt_b,(-0.2355))",
        "cat_b": "UC",
        "psi": "43"
    },
    {
        "ang": "80",
        "tip": "ER80-05",
        "part_no": "40270-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate": "0.5",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.079",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.354",
        "r_max": "0.707",
        "vmd_s": "631.49*Math.pow(pt,-0.2531)",
        "141_s": "11.986*Math.log(pt)-24.472",
        "200_s": "17.263*Math.log(pt)-27.575",
        "600_s": "100-5.9766*Math.pow(pt,(-0.0345))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.075",
        "orf_eff": "0.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.104",
        "p_max": "59",
        "r_min_b": "0.084",
        "r_max_b": "0.607",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "631.49*Math.pow(pt_b,-0.2531)",
        "141_b": "11.986*Math.log(pt_b)-24.472",
        "200_b": "17.263*Math.log(pt_b)-27.575",
        "600_b": "100-5.9766*Math.pow(pt_b,(-0.0345))",
        "cat_b": "UC",
        "psi": "44"
    },
    {
        "ang": "80",
        "tip": "ER80-06",
        "part_no": "40270-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate": "0.6",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.095",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.424",
        "r_max": "0.849",
        "vmd_s": "594.42*Math.pow(pt,-0.2047)",
        "141_s": "10.829*Math.log(pt)-20.313",
        "200_s": "13.154*Math.log(pt)-19.34",
        "600_s": "100-5.0974*Math.pow(pt,(0.1625))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.088",
        "orf_eff": "0.56",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.150",
        "p_max": "57",
        "r_min_b": "0.099",
        "r_max_b": "0.713",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "594.42*Math.pow(pt_b,-0.2047)",
        "141_b": "10.829*Math.log(pt_b)-20.313",
        "200_b": "13.154*Math.log(pt_b)-19.34",
        "600_b": "100-5.0974*Math.pow(pt_b,(0.1625))",
        "cat_b": "UC",
        "psi": "46"
    },
    {
        "ang": "80",
        "tip": "ER80-08",
        "part_no": "40270-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate": "0.8",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.126",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.566",
        "r_max": "1.131",
        "vmd_s": "1078.6*Math.pow(pt,-0.3602)",
        "141_s": "12.475*Math.log(pt)-25.383",
        "200_s": "16.004*Math.log(pt)-25.116",
        "600_s": "100-186.04*Math.pow(pt,(-0.8714))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.112",
        "orf_eff": "0.71",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.266",
        "p_max": "51",
        "r_min_b": "0.126",
        "r_max_b": "0.906",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1078.6*Math.pow(pt_b,-0.3602)",
        "141_b": "12.475*Math.log(pt_b)-25.383",
        "200_b": "16.004*Math.log(pt_b)-25.116",
        "600_b": "100-186.04*Math.pow(pt_b,(-0.8714))",
        "cat_b": "UC",
        "psi": "51"
    },
    {
        "ang": "80",
        "tip": "ER80-10",
        "part_no": "40270-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate": "1",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.158",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.707",
        "r_max": "1.414",
        "vmd_s": "1140.1*Math.pow(pt,-0.3045)",
        "141_s": "8.229*Math.log(pt)-16.079",
        "200_s": "12.151*Math.log(pt)-20.728",
        "600_s": "100-97.141*Math.pow(pt,(-0.4911))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.133",
        "orf_eff": "0.84",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.416",
        "p_max": "46",
        "r_min_b": "0.149",
        "r_max_b": "1.071",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1140.1*Math.pow(pt_b,-0.3045)",
        "141_b": "8.229*Math.log(pt_b)-16.079",
        "200_b": "12.151*Math.log(pt_b)-20.728",
        "600_b": "100-97.141*Math.pow(pt_b,(-0.4911))",
        "cat_b": "UC",
        "psi": "57"
    },
    {
        "ang": "80",
        "tip": "ER80-125",
        "part_no": "40270-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate": "1.25",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.198",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.884",
        "r_max": "1.768",
        "vmd_s": "995.77*Math.pow(pt,-0.259)",
        "141_s": "5.5198*Math.log(pt)-7.4765",
        "200_s": "8.8095*Math.log(pt)-9.1844",
        "600_s": "100-113.1*Math.pow(pt,(-0.5196))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.154",
        "orf_eff": "0.97",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.650",
        "p_max": "39",
        "r_min_b": "0.172",
        "r_max_b": "1.240",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "995.77*Math.pow(pt_b,-0.259)",
        "141_b": "5.5198*Math.log(pt_b)-7.4765",
        "200_b": "8.8095*Math.log(pt_b)-9.1844",
        "600_b": "100-113.1*Math.pow(pt_b,(-0.5196))",
        "cat_b": "UC",
        "psi": "66"
    },
    {
        "ang": "80",
        "tip": "ER80-15",
        "part_no": "40270-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate": "1.5",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.237",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.061",
        "r_max": "2.121",
        "vmd_s": "1107.3*Math.pow(pt,-0.2907)",
        "141_s": "7.6316*Math.log(pt)-15.788",
        "200_s": "12.011*Math.log(pt)-22.216",
        "600_s": "100-64.393*Math.pow(pt,(-0.3303))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.170",
        "orf_eff": "1.08",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.937",
        "p_max": "34",
        "r_min_b": "0.191",
        "r_max_b": "1.374",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1107.3*Math.pow(pt_b,-0.2907)",
        "141_b": "7.6316*Math.log(pt_b)-15.788",
        "200_b": "12.011*Math.log(pt_b)-22.216",
        "600_b": "100-64.393*Math.pow(pt_b,(-0.3303))",
        "cat_b": "UC",
        "psi": "77"
    },
    {
        "ang": "80",
        "tip": "ER80-20",
        "part_no": "40270-20",
        "color": "Tan", "csscolor": "tip-tan",
        "tip_rate": "2",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.316",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.414",
        "r_max": "2.828",
        "vmd_s": "1111.5*Math.pow(pt,-0.2591)",
        "141_s": "5.9039*Math.log(pt)-11.252",
        "200_s": "9.5861*Math.log(pt)-16.846",
        "600_s": "100-137.6*Math.pow(pt,(-0.4785))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.194",
        "orf_eff": "1.23",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "2.665",
        "p_max": "24",
        "r_min_b": "0.217",
        "r_max_b": "1.562",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1111.5*Math.pow(pt_b,-0.2591)",
        "141_b": "5.9039*Math.log(pt_b)-11.252",
        "200_b": "9.5861*Math.log(pt_b)-16.846",
        "600_b": "100-137.6*Math.pow(pt_b,(-0.4785))",
        "cat_b": "UC",
        "psi": "107"
    },
    {
        "ang": "80",
        "tip": "ER80-25",
        "part_no": "40270-25",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "2.5",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.395",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.768",
        "r_max": "3.536",
        "vmd_s": "1155.7*Math.pow(pt,-0.2697)",
        "141_s": "5.5917*Math.log(pt)-9.4402",
        "200_s": "9.8963*Math.log(pt)-17.337",
        "600_s": "100-96.14*Math.pow(pt,(-0.366))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.208",
        "orf_eff": "1.32",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "3.601",
        "p_max": "18",
        "r_min_b": "0.233",
        "r_max_b": "1.679",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1155.7*Math.pow(pt_b,-0.2697)",
        "141_b": "5.5917*Math.log(pt_b)-9.4402",
        "200_b": "9.8963*Math.log(pt_b)-17.337",
        "600_b": "100-96.14*Math.pow(pt_b,(-0.366))",
        "cat_b": "UC",
        "psi": "144"
    },
    {
        "ang": "80",
        "tip": "ER80-30",
        "part_no": "40270-30",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "3",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.474",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "2.121",
        "r_max": "4.243",
        "vmd_s": "1234*Math.pow(pt,-0.2771)",
        "141_s": "4.588*Math.log(pt)-8.8927",
        "200_s": "8.3306*Math.log(pt)-14.241",
        "600_s": "100-117.2*Math.pow(pt,(-0.3932))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.218",
        "orf_eff": "1.38",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "4.746",
        "p_max": "14",
        "r_min_b": "0.243",
        "r_max_b": "1.755",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1234*Math.pow(pt_b,-0.2771)",
        "141_b": "4.588*Math.log(pt_b)-8.8927",
        "200_b": "8.3306*Math.log(pt_b)-14.241",
        "600_b": "100-117.2*Math.pow(pt_b,(-0.3932))",
        "cat_b": "UC",
        "psi": "190"
    },
    {
        "ang": "80",
        "tip": "ER80-40",
        "part_no": "40270-40",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "4",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.632",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "2.828",
        "r_max": "5.657",
        "vmd_s": "1191.1*Math.pow(pt,-0.2677)",
        "141_s": "4.588*Math.log(pt)-8.8927",
        "200_s": "8.8396*Math.log(pt)-16.931",
        "600_s": "100-113.97*Math.pow(pt,(-0.386))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.229",
        "orf_eff": "1.45",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "7.660",
        "p_max": "8",
        "r_min_b": "0.255",
        "r_max_b": "1.842",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1191.1*Math.pow(pt_b,-0.2677)",
        "141_b": "4.588*Math.log(pt_b)-8.8927",
        "200_b": "8.8396*Math.log(pt_b)-16.931",
        "600_b": "100-113.97*Math.pow(pt_b,(-0.386))",
        "cat_b": "UC",
        "psi": "307"
    },
    {
        "ang": "80",
        "tip": "ER80-50",
        "part_no": "40270-50",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "5",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.791",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "3.536",
        "r_max": "7.071",
        "vmd_s": "1184.9*Math.pow(pt,-0.2623)",
        "141_s": "3.4627*Math.log(pt)-5.399",
        "200_s": "7.4426*Math.log(pt)-12.685",
        "600_s": "100-115.33*Math.pow(pt,(-0.3794))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.234",
        "orf_eff": "1.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "11.406",
        "p_max": "6",
        "r_min_b": "0.262",
        "r_max_b": "1.887",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1184.9*Math.pow(pt_b,-0.2623)",
        "141_b": "3.4627*Math.log(pt_b)-5.399",
        "200_b": "7.4426*Math.log(pt_b)-12.685",
        "600_b": "100-115.33*Math.pow(pt_b,(-0.3794))",
        "cat_b": "UC",
        "psi": "456"
    },
    {
        "ang": "80",
        "tip": "ER80-60",
        "part_no": "40270-60",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "6",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.949",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "4.243",
        "r_max": "8.485",
        "vmd_s": "1037.8*Math.pow(pt,-0.2299)",
        "141_s": "4.1517*Math.log(pt)-6.859",
        "200_s": "7.7614*Math.log(pt)-12.884",
        "600_s": "100-39.361*Math.exp((-0.007*pt))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.237",
        "orf_eff": "1.50",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "15.984",
        "p_max": "4",
        "r_min_b": "0.265",
        "r_max_b": "1.913",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1037.8*Math.pow(pt_b,-0.2299)",
        "141_b": "4.1517*Math.log(pt_b)-6.859",
        "200_b": "7.7614*Math.log(pt_b)-12.884",
        "600_b": "100-39.361*Math.exp((-0.007*pt_b))",
        "cat_b": "UC",
        "psi": "640"
    },
    {
        "ang": "80",
        "tip": "SR80-01",
        "part_no": "40288-01",
        "color": "Orange", "csscolor": "tip-orange",
        "tip_rate": "0.1",
        "pre_orf": "R015",
        "pre-orf_no": "40285-015",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.016",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.079",
        "r_max": "0.141",
        "vmd_s": "1549.7*Math.pow(pt,(-0.5567))",
        "141_s": "30.057*Math.log(pt)-81.727",
        "200_s": "42.509*Math.log(pt)-105.66",
        "600_s": "100-8.1464*Math.pow(pt,(-0.3059))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.016",
        "orf_eff": "0.10",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.004",
        "p_max": "65",
        "r_min_b": "0.018",
        "r_max_b": "0.127",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1549.7*Math.pow(pt_b,(-0.5567))",
        "141_b": "30.057*Math.log(pt_b)-81.727",
        "200_b": "42.509*Math.log(pt_b)-105.66",
        "600_b": "100-8.1464*Math.pow(pt_b,(-0.3059))",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "SR80-015",
        "part_no": "40288-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate": "0.15",
        "pre_orf": "R02",
        "pre-orf_no": "40285-02",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.024",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.119",
        "r_max": "0.212",
        "vmd_s": "1264.3*Math.pow(pt,(-0.4622))",
        "141_s": "19.774*Math.log(pt)-51.001",
        "200_s": "31.652*Math.log(pt)-76.006",
        "600_s": "100-84.433*Math.pow(pt,(-0.8425))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.024",
        "orf_eff": "0.15",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.009",
        "p_max": "64",
        "r_min_b": "0.026",
        "r_max_b": "0.190",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1264.3*Math.pow(pt_b,(-0.4622))",
        "141_b": "19.774*Math.log(pt_b)-51.001",
        "200_b": "31.652*Math.log(pt_b)-76.006",
        "600_b": "100-84.433*Math.pow(pt_b,(-0.8425))",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "SR80-02",
        "part_no": "40288-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate": "0.2",
        "pre_orf": "R025",
        "pre-orf_no": "40285-025",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.032",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.158",
        "r_max": "0.283",
        "vmd_s": "811.97*Math.pow(pt,(-0.3382))",
        "141_s": "16.638*Math.log(pt)-40.918",
        "200_s": "24.697*Math.log(pt)-52.727",
        "600_s": "100-149.39*Math.pow(pt,(-1.0057))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.031",
        "orf_eff": "0.20",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.017",
        "p_max": "64",
        "r_min_b": "0.035",
        "r_max_b": "0.253",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "811.97*Math.pow(pt_b,(-0.3382))",
        "141_b": "16.638*Math.log(pt_b)-40.918",
        "200_b": "24.697*Math.log(pt_b)-52.727",
        "600_b": "100-149.39*Math.pow(pt_b,(-1.0057))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "SR80-025",
        "part_no": "40288-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate": "0.25",
        "pre_orf": "R03",
        "pre-orf_no": "40285-03",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.040",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.198",
        "r_max": "0.354",
        "vmd_s": "961.23*Math.pow(pt,(-0.3463))",
        "141_s": "12.847*Math.log(pt)-32.298",
        "200_s": "21.9*Math.log(pt)-50.887",
        "600_s": "100-175.53*Math.pow(pt,(-0.9326))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.039",
        "orf_eff": "0.25",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.026",
        "p_max": "63",
        "r_min_b": "0.044",
        "r_max_b": "0.315",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "961.23*Math.pow(pt_b,(-0.3463))",
        "141_b": "12.847*Math.log(pt_b)-32.298",
        "200_b": "21.9*Math.log(pt_b)-50.887",
        "600_b": "100-175.53*Math.pow(pt_b,(-0.9326))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "SR80-03",
        "part_no": "40288-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate": "0.3",
        "pre_orf": "R03",
        "pre-orf_no": "40285-03",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.047",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.237",
        "r_max": "0.424",
        "vmd_s": "1219.7*Math.pow(pt,(-0.3719))",
        "141_s": "10.794*Math.log(pt)-27.454",
        "200_s": "19.447*Math.log(pt)-48.844",
        "600_s": "100-74.911*Math.pow(pt,(-0.5694))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.047",
        "orf_eff": "0.29",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.037",
        "p_max": "63",
        "r_min_b": "0.052",
        "r_max_b": "0.375",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1219.7*Math.pow(pt_b,(-0.3719))",
        "141_b": "10.794*Math.log(pt_b)-27.454",
        "200_b": "19.447*Math.log(pt_b)-48.844",
        "600_b": "100-74.911*Math.pow(pt_b,(-0.5694))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "SR80-04",
        "part_no": "40288-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate": "0.4",
        "pre_orf": "R06",
        "pre-orf_no": "40285-06",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.063",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.316",
        "r_max": "0.566",
        "vmd_s": "1190.9*Math.pow(pt,(-0.365))",
        "141_s": "9.4906*Math.log(pt)-25.212",
        "200_s": "18.455*Math.log(pt)-43.926",
        "600_s": "100-110.7*Math.pow(pt,(-0.63))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.061",
        "orf_eff": "0.39",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.067",
        "p_max": "61",
        "r_min_b": "0.068",
        "r_max_b": "0.494",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1190.9*Math.pow(pt_b,(-0.365))",
        "141_b": "9.4906*Math.log(pt_b)-25.212",
        "200_b": "18.455*Math.log(pt_b)-43.926",
        "600_b": "100-110.7*Math.pow(pt_b,(-0.63))",
        "cat_b": "UC",
        "psi": "43"
    },
    {
        "ang": "80",
        "tip": "SR80-05",
        "part_no": "40288-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate": "0.5",
        "pre_orf": "R06",
        "pre-orf_no": "40285-06",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.079",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.395",
        "r_max": "0.707",
        "vmd_s": "1382.8*Math.pow(pt,(-0.3787))",
        "141_s": "9.4906*Math.log(pt)-25.212",
        "200_s": "17.31*Math.log(pt)-43.958",
        "600_s": "100-141.06*Math.pow(pt,(-0.6192))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.075",
        "orf_eff": "0.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.104",
        "p_max": "59",
        "r_min_b": "0.084",
        "r_max_b": "0.607",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1382.8*Math.pow(pt_b,(-0.3787))",
        "141_b": "9.4906*Math.log(pt_b)-25.212",
        "200_b": "17.31*Math.log(pt_b)-43.958",
        "600_b": "100-141.06*Math.pow(pt_b,(-0.6192))",
        "cat_b": "UC",
        "psi": "44"
    },
    {
        "ang": "80",
        "tip": "SR80-06",
        "part_no": "40288-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate": "0.6",
        "pre_orf": "R08",
        "pre-orf_no": "40285-08",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.095",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.474",
        "r_max": "0.849",
        "vmd_s": "1007.8*Math.pow(pt,(-0.2575))",
        "141_s": "5.3155*Math.log(pt)-12.878",
        "200_s": "10.378*Math.log(pt)-24.082",
        "600_s": "100-199.26*Math.pow(pt,(-0.685))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.088",
        "orf_eff": "0.56",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.150",
        "p_max": "57",
        "r_min_b": "0.099",
        "r_max_b": "0.713",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1007.8*Math.pow(pt_b,(-0.2575))",
        "141_b": "5.3155*Math.log(pt_b)-12.878",
        "200_b": "10.378*Math.log(pt_b)-24.082",
        "600_b": "100-199.26*Math.pow(pt_b,(-0.685))",
        "cat_b": "UC",
        "psi": "46"
    },
    {
        "ang": "80",
        "tip": "SR80-08",
        "part_no": "40288-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate": "0.8",
        "pre_orf": "R10",
        "pre-orf_no": "40285-10",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.126",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.632",
        "r_max": "1.131",
        "vmd_s": "-143.51*Math.log(pt)+977.97",
        "141_s": "5.2051*Math.log(pt)-10.089",
        "200_s": "8.0275*Math.log(pt)-15.006",
        "600_s": "100-391.04*Math.pow(pt,(-0.6617))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.112",
        "orf_eff": "0.71",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.266",
        "p_max": "51",
        "r_min_b": "0.126",
        "r_max_b": "0.906",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-143.51*Math.log(pt_b)+977.97",
        "141_b": "5.2051*Math.log(pt_b)-10.089",
        "200_b": "8.0275*Math.log(pt_b)-15.006",
        "600_b": "100-391.04*Math.pow(pt_b,(-0.6617))",
        "cat_b": "UC",
        "psi": "51"
    },
    {
        "ang": "80",
        "tip": "SR80-10",
        "part_no": "40288-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate": "1",
        "pre_orf": "R12.5",
        "pre-orf_no": "40285-125",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.158",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.791",
        "r_max": "1.414",
        "vmd_s": "-138.79*Math.log(pt)+983.67",
        "141_s": "4.3822*Math.log(pt)-8.3043",
        "200_s": "7.9357*Math.log(pt)-16.38",
        "600_s": "100-373.88*Math.pow(pt,(-0.6241))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.133",
        "orf_eff": "0.84",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.416",
        "p_max": "46",
        "r_min_b": "0.149",
        "r_max_b": "1.071",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-138.79*Math.log(pt_b)+983.67",
        "141_b": "4.3822*Math.log(pt_b)-8.3043",
        "200_b": "7.9357*Math.log(pt_b)-16.38",
        "600_b": "100-373.88*Math.pow(pt_b,(-0.6241))",
        "cat_b": "UC",
        "psi": "57"
    },
    {
        "ang": "80",
        "tip": "SR80-125",
        "part_no": "40288-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate": "1.25",
        "pre_orf": "R20",
        "pre-orf_no": "40285-20",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.198",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.988",
        "r_max": "1.768",
        "vmd_s": "-120.58*Math.log(pt)+919.07",
        "141_s": "4.3649*Math.log(pt)-7.9745",
        "200_s": "7.0187*Math.log(pt)-12.75",
        "600_s": "100-231.91*Math.pow(pt,(-0.4828))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.154",
        "orf_eff": "0.97",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.650",
        "p_max": "39",
        "r_min_b": "0.172",
        "r_max_b": "1.240",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-120.58*Math.log(pt_b)+919.07",
        "141_b": "4.3649*Math.log(pt_b)-7.9745",
        "200_b": "7.0187*Math.log(pt_b)-12.75",
        "600_b": "100-231.91*Math.pow(pt_b,(-0.4828))",
        "cat_b": "UC",
        "psi": "66"
    },
    {
        "ang": "80",
        "tip": "SR80-15",
        "part_no": "40288-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate": "1.5",
        "pre_orf": "R20",
        "pre-orf_no": "40285-20",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.237",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.186",
        "r_max": "2.121",
        "vmd_s": "-120.03*Math.log(pt)+961.95",
        "141_s": "2.1862*Math.log(pt)-1.7508",
        "200_s": "5.0026*Math.log(pt)-8.0897",
        "600_s": "100-222.4*Math.pow(pt,(-0.424))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.170",
        "orf_eff": "1.08",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.937",
        "p_max": "34",
        "r_min_b": "0.191",
        "r_max_b": "1.374",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-120.03*Math.log(pt_b)+961.95",
        "141_b": "2.1862*Math.log(pt_b)-1.7508",
        "200_b": "5.0026*Math.log(pt_b)-8.0897",
        "600_b": "100-222.4*Math.pow(pt_b,(-0.424))",
        "cat_b": "UC",
        "psi": "77"
    },
    {
        "ang": "80",
        "tip": "SR80-20",
        "part_no": "40288-20",
        "color": "Tan", "csscolor": "tip-tan",
        "tip_rate": "2",
        "pre_orf": "R25",
        "pre-orf_no": "40285-25",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.316",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.581",
        "r_max": "2.828",
        "vmd_s": "-126.05*Math.log(pt)+979.75",
        "141_s": "2.2654*Math.log(pt)-2.2416",
        "200_s": "4.9803*Math.log(pt)-8.4879",
        "600_s": "100-227.97*Math.pow(pt,(-0.435))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.194",
        "orf_eff": "1.23",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "2.665",
        "p_max": "24",
        "r_min_b": "0.217",
        "r_max_b": "1.562",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-126.05*Math.log(pt_b)+979.75",
        "141_b": "2.2654*Math.log(pt_b)-2.2416",
        "200_b": "4.9803*Math.log(pt_b)-8.4879",
        "600_b": "100-227.97*Math.pow(pt_b,(-0.435))",
        "cat_b": "UC",
        "psi": "107"
    },
    {
        "ang": "80",
        "tip": "SR80-25",
        "part_no": "40288-25",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "2.5",
        "pre_orf": "R40",
        "pre-orf_no": "40285-40",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.395",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.976",
        "r_max": "3.536",
        "vmd_s": "-111.42*Math.log(pt)+890.25",
        "141_s": "2.7885*Math.log(pt)-3.993",
        "200_s": "4.5657*Math.log(pt)-6.6208",
        "600_s": "100-170.42*Math.pow(pt,(-0.3849))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.208",
        "orf_eff": "1.32",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "3.601",
        "p_max": "18",
        "r_min_b": "0.233",
        "r_max_b": "1.679",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-111.42*Math.log(pt_b)+890.25",
        "141_b": "2.7885*Math.log(pt_b)-3.993",
        "200_b": "4.5657*Math.log(pt_b)-6.6208",
        "600_b": "100-170.42*Math.pow(pt_b,(-0.3849))",
        "cat_b": "UC",
        "psi": "144"
    },
    {
        "ang": "80",
        "tip": "SR80-30",
        "part_no": "40288-30",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "3",
        "pre_orf": "R40",
        "pre-orf_no": "40285-40",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.474",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "2.372",
        "r_max": "4.243",
        "vmd_s": "1164.6*Math.pow(pt,(-0.2437))",
        "141_s": "2.4093*Math.log(pt)-3.369",
        "200_s": "4.9746*Math.log(pt)-8.5738",
        "600_s": "100-177.52*Math.pow(pt,(-0.3958))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.218",
        "orf_eff": "1.38",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "4.746",
        "p_max": "14",
        "r_min_b": "0.243",
        "r_max_b": "1.755",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1164.6*Math.pow(pt_b,(-0.2437))",
        "141_b": "2.4093*Math.log(pt_b)-3.369",
        "200_b": "4.9746*Math.log(pt_b)-8.5738",
        "600_b": "100-177.52*Math.pow(pt_b,(-0.3958))",
        "cat_b": "UC",
        "psi": "190"
    },
    {
        "ang": "80",
        "tip": "SR80-40",
        "part_no": "40288-40",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "4",
        "pre_orf": "R50",
        "pre-orf_no": "40285-50",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.632",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "3.162",
        "r_max": "5.657",
        "vmd_s": "1038.4*Math.pow(pt,(-0.2166))",
        "141_s": "2.097*Math.log(pt)-2.6572",
        "200_s": "4.5815*Math.log(pt)-7.3353",
        "600_s": "100-148.42*Math.pow(pt,(-0.3571))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.229",
        "orf_eff": "1.45",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "7.660",
        "p_max": "8",
        "r_min_b": "0.255",
        "r_max_b": "1.842",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1038.4*Math.pow(pt_b,(-0.2166))",
        "141_b": "2.097*Math.log(pt_b)-2.6572",
        "200_b": "4.5815*Math.log(pt_b)-7.3353",
        "600_b": "100-148.42*Math.pow(pt_b,(-0.3571))",
        "cat_b": "UC",
        "psi": "307"
    },
    {
        "ang": "80",
        "tip": "SR80-50",
        "part_no": "40288-50",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "5",
        "pre_orf": "R50",
        "pre-orf_no": "40285-50",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.791",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "3.953",
        "r_max": "7.071",
        "vmd_s": "1200*Math.pow(pt,-0.2495)",
        "141_s": "2.097*Math.log(pt)-2.6572",
        "200_s": "7.4838*Math.log(pt)-14.869",
        "600_s": "100-55.271*Math.pow(pt,(-0.0092)*pt)",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.234",
        "orf_eff": "1.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "11.406",
        "p_max": "6",
        "r_min_b": "0.262",
        "r_max_b": "1.887",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1200*Math.pow(pt_b,-0.2495)",
        "141_b": "2.097*Math.log(pt_b)-2.6572",
        "200_b": "7.4838*Math.log(pt_b)-14.869",
        "600_b": "100-55.271*Math.pow(pt_b,(-0.0092)*pt_b)",
        "cat_b": "UC",
        "psi": "456"
    },
    {
        "ang": "80",
        "tip": "MR80-005",
        "part_no": "40290-005",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "0.05",
        "pre_orf": "R005",
        "pre-orf_no": "40285-005",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.008",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.040",
        "r_max": "0.071",
        "vmd_s": "1524*Math.pow(pt,-0.5487)",
        "141_s": "31.908*Math.log(pt)-91.892",
        "200_s": "51.123*Math.log(pt)-137.55",
        "600_s": "100.0",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.008",
        "orf_eff": "0.05",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.001",
        "p_max": "65",
        "r_min_b": "0.009",
        "r_max_b": "0.064",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1524*Math.pow(pt_b,-0.5487)",
        "141_b": "31.908*Math.log(pt_b)-91.892",
        "200_b": "51.123*Math.log(pt_b)-137.55",
        "600_b": "100.0",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "MR80-0067",
        "part_no": "40290-007",
        "color": "Pink", "csscolor": "tip-pink",
        "tip_rate": "0.067",
        "pre_orf": "R0067",
        "pre-orf_no": "40285-007",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.011",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.053",
        "r_max": "0.095",
        "vmd_s": "1210.2*Math.pow(pt,-0.5139)",
        "141_s": "32.349*Math.log(pt)-86.353",
        "200_s": "Math.min(45.197*Math.log(pt)-106.29,100)",
        "600_s": "100",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.011",
        "orf_eff": "0.07",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.002",
        "p_max": "65",
        "r_min_b": "0.012",
        "r_max_b": "0.085",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1210.2*Math.pow(pt_b,-0.5139)",
        "141_b": "32.349*Math.log(pt_b)-86.353",
        "200_b": "Math.min(45.197*Math.log(pt_b)-106.29,100)",
        "600_b": "100",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "MR80-01",
        "part_no": "40290-01",
        "color": "Orange", "csscolor": "tip-orange",
        "tip_rate": "0.1",
        "pre_orf": "RO1",
        "pre-orf_no": "40285-01",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.016",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.079",
        "r_max": "0.141",
        "vmd_s": "1044*Math.pow(pt,-0.4599)",
        "141_s": "25.497*Math.log(pt)-64.02",
        "200_s": "34.542*Math.log(pt)-73.88",
        "600_s": "100-0.016888*pt+2.0882",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.016",
        "orf_eff": "0.10",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.004",
        "p_max": "65",
        "r_min_b": "0.018",
        "r_max_b": "0.127",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1044*Math.pow(pt_b,-0.4599)",
        "141_b": "25.497*Math.log(pt_b)-64.02",
        "200_b": "34.542*Math.log(pt_b)-73.88",
        "600_b": "100-0.016888*pt_b+2.0882",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "MR80-015",
        "part_no": "40290-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate": "0.15",
        "pre_orf": "R015",
        "pre-orf_no": "40285-015",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.024",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.119",
        "r_max": "0.212",
        "vmd_s": "1512.8*Math.pow(pt,-0.454)",
        "141_s": "13.6*Math.log(pt)-36.141",
        "200_s": "24.418*Math.log(pt)-61.818",
        "600_s": "100-1620.2*Math.pow(pt,(-1.6499))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.024",
        "orf_eff": "0.15",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.009",
        "p_max": "64",
        "r_min_b": "0.026",
        "r_max_b": "0.190",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1512.8*Math.pow(pt_b,-0.454)",
        "141_b": "13.6*Math.log(pt_b)-36.141",
        "200_b": "24.418*Math.log(pt_b)-61.818",
        "600_b": "100-1620.2*Math.pow(pt_b,(-1.6499))",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "MR80-02",
        "part_no": "40290-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate": "0.2",
        "pre_orf": "R02",
        "pre-orf_no": "40285-02",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.032",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.158",
        "r_max": "0.283",
        "vmd_s": "952.77*Math.pow(pt,-0.3155)",
        "141_s": "10.824*Math.log(pt)-28.67",
        "200_s": "19.187*Math.log(pt)-47.265",
        "600_s": "100-20.177*Math.pow(pt,(-0.3367))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.031",
        "orf_eff": "0.20",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.017",
        "p_max": "64",
        "r_min_b": "0.035",
        "r_max_b": "0.253",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "952.77*Math.pow(pt_b,-0.3155)",
        "141_b": "10.824*Math.log(pt_b)-28.67",
        "200_b": "19.187*Math.log(pt_b)-47.265",
        "600_b": "100-20.177*Math.pow(pt_b,(-0.3367))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "MR80-025",
        "part_no": "40290-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate": "0.25",
        "pre_orf": "R025",
        "pre-orf_no": "40285-025",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.040",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.198",
        "r_max": "0.354",
        "vmd_s": "1457.8*Math.pow(pt,-0.3627)",
        "141_s": "6.5235*Math.log(pt)-17.569",
        "200_s": "13.114*Math.log(pt)-34.429",
        "600_s": "100-246.52*Math.pow(pt,(-0.7514))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.039",
        "orf_eff": "0.25",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.026",
        "p_max": "63",
        "r_min_b": "0.044",
        "r_max_b": "0.315",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1457.8*Math.pow(pt_b,-0.3627)",
        "141_b": "6.5235*Math.log(pt_b)-17.569",
        "200_b": "13.114*Math.log(pt_b)-34.429",
        "600_b": "100-246.52*Math.pow(pt_b,(-0.7514))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "MR80-03",
        "part_no": "40290-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate": "0.3",
        "pre_orf": "R03",
        "pre-orf_no": "40285-03",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.047",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.237",
        "r_max": "0.424",
        "vmd_s": "1457.7*Math.pow(pt,-0.3577)",
        "141_s": "6.5781*Math.log(pt)-17.705",
        "200_s": "12.505*Math.log(pt)-32.26",
        "600_s": "100-360.66*Math.pow(pt,(-0.8618))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.047",
        "orf_eff": "0.29",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.037",
        "p_max": "63",
        "r_min_b": "0.052",
        "r_max_b": "0.375",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1457.7*Math.pow(pt_b,-0.3577)",
        "141_b": "6.5781*Math.log(pt_b)-17.705",
        "200_b": "12.505*Math.log(pt_b)-32.26",
        "600_b": "100-360.66*Math.pow(pt_b,(-0.8618))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "MR80-04",
        "part_no": "40290-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate": "0.4",
        "pre_orf": "R04",
        "pre-orf_no": "40285-04",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.063",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.316",
        "r_max": "0.566",
        "vmd_s": "1168.9*Math.pow(pt,-0.3008)",
        "141_s": "6.8117*Math.log(pt)-17.868",
        "200_s": "12.349*Math.log(pt)-30.654",
        "600_s": "100-206.56*Math.pow(pt,(-0.6906))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.061",
        "orf_eff": "0.39",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.067",
        "p_max": "61",
        "r_min_b": "0.068",
        "r_max_b": "0.494",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1168.9*Math.pow(pt_b,-0.3008)",
        "141_b": "6.8117*Math.log(pt_b)-17.868",
        "200_b": "12.349*Math.log(pt_b)-30.654",
        "600_b": "100-206.56*Math.pow(pt_b,(-0.6906))",
        "cat_b": "UC",
        "psi": "43"
    },
    {
        "ang": "80",
        "tip": "MR80-05",
        "part_no": "40290-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate": "0.5",
        "pre_orf": "R05",
        "pre-orf_no": "40285-05",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.079",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.395",
        "r_max": "0.707",
        "vmd_s": "1275.3*Math.pow(pt,-0.2732)",
        "141_s": "4.0751*Math.log(pt)-10.85",
        "200_s": "8.13*Math.log(pt)-20.882",
        "600_s": "100-303.27*Math.pow(pt,(-0.6579))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.075",
        "orf_eff": "0.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.104",
        "p_max": "59",
        "r_min_b": "0.084",
        "r_max_b": "0.607",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1275.3*Math.pow(pt_b,-0.2732)",
        "141_b": "4.0751*Math.log(pt_b)-10.85",
        "200_b": "8.13*Math.log(pt_b)-20.882",
        "600_b": "100-303.27*Math.pow(pt_b,(-0.6579))",
        "cat_b": "UC",
        "psi": "44"
    },
    {
        "ang": "80",
        "tip": "MR80-06",
        "part_no": "40290-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate": "0.6",
        "pre_orf": "R06",
        "pre-orf_no": "40285-06",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.095",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.474",
        "r_max": "0.849",
        "vmd_s": "1156.1*Math.pow(pt,-0.2314)",
        "141_s": "3.3781*Math.log(pt)-9.0044",
        "200_s": "6.6949*Math.log(pt)-17.153",
        "600_s": "100-263.61*Math.pow(pt,(-0.5864))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.088",
        "orf_eff": "0.56",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.150",
        "p_max": "57",
        "r_min_b": "0.099",
        "r_max_b": "0.713",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1156.1*Math.pow(pt_b,-0.2314)",
        "141_b": "3.3781*Math.log(pt_b)-9.0044",
        "200_b": "6.6949*Math.log(pt_b)-17.153",
        "600_b": "100-263.61*Math.pow(pt_b,(-0.5864))",
        "cat_b": "UC",
        "psi": "46"
    },
    {
        "ang": "80",
        "tip": "MR80-08",
        "part_no": "40290-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate": "0.8",
        "pre_orf": "R08",
        "pre-orf_no": "40285-08",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.126",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.632",
        "r_max": "1.131",
        "vmd_s": "1347.4*Math.pow(pt,-0.269)",
        "141_s": "5.4257*Math.log(pt)-12.132",
        "200_s": "10.71*Math.log(pt)-25.621",
        "600_s": "100-282.3*Math.pow(pt,(-0.6013))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.112",
        "orf_eff": "0.71",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.266",
        "p_max": "51",
        "r_min_b": "0.126",
        "r_max_b": "0.906",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1347.4*Math.pow(pt_b,-0.269)",
        "141_b": "5.4257*Math.log(pt_b)-12.132",
        "200_b": "10.71*Math.log(pt_b)-25.621",
        "600_b": "100-282.3*Math.pow(pt_b,(-0.6013))",
        "cat_b": "UC",
        "psi": "51"
    },
    {
        "ang": "80",
        "tip": "MR80-10",
        "part_no": "40290-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate": "1",
        "pre_orf": "R010",
        "pre-orf_no": "40285-10",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.158",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.791",
        "r_max": "1.414",
        "vmd_s": "1145.9*Math.pow(pt,-0.2179)",
        "141_s": "3.6932*Math.log(pt)-7.5442",
        "200_s": "8.7734*Math.log(pt)-21.189",
        "600_s": "100-172.03*Math.pow(pt,(-0.4475))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.133",
        "orf_eff": "0.84",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.416",
        "p_max": "46",
        "r_min_b": "0.149",
        "r_max_b": "1.071",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1145.9*Math.pow(pt_b,-0.2179)",
        "141_b": "3.6932*Math.log(pt_b)-7.5442",
        "200_b": "8.7734*Math.log(pt_b)-21.189",
        "600_b": "100-172.03*Math.pow(pt_b,(-0.4475))",
        "cat_b": "UC",
        "psi": "57"
    },
    {
        "ang": "80",
        "tip": "MR80-125",
        "part_no": "40290-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate": "1.25",
        "pre_orf": "R12.5",
        "pre-orf_no": "40285-125",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.198",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.988",
        "r_max": "1.768",
        "vmd_s": "1057.2*Math.pow(pt,-0.174)",
        "141_s": "3.5494*Math.log(pt)-6.8168",
        "200_s": "7.0738*Math.log(pt)-15.066",
        "600_s": "100-151.91*Math.pow(pt,(-0.3629))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.154",
        "orf_eff": "0.97",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.650",
        "p_max": "39",
        "r_min_b": "0.172",
        "r_max_b": "1.240",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1057.2*Math.pow(pt_b,-0.174)",
        "141_b": "3.5494*Math.log(pt_b)-6.8168",
        "200_b": "7.0738*Math.log(pt_b)-15.066",
        "600_b": "100-151.91*Math.pow(pt_b,(-0.3629))",
        "cat_b": "UC",
        "psi": "66"
    },
    {
        "ang": "80",
        "tip": "MR80-15",
        "part_no": "40290-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate": "1.5",
        "pre_orf": "R15",
        "pre-orf_no": "40285-15",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.237",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.186",
        "r_max": "2.121",
        "vmd_s": "1114.6*Math.pow(pt,-0.2284)",
        "141_s": "4.5457*Math.log(pt)-8.3372",
        "200_s": "7.986*Math.log(pt)-14.463",
        "600_s": "100-143.91*Math.pow(pt,(-0.4282))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.170",
        "orf_eff": "1.08",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.937",
        "p_max": "34",
        "r_min_b": "0.191",
        "r_max_b": "1.374",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1114.6*Math.pow(pt_b,-0.2284)",
        "141_b": "4.5457*Math.log(pt_b)-8.3372",
        "200_b": "7.986*Math.log(pt_b)-14.463",
        "600_b": "100-143.91*Math.pow(pt_b,(-0.4282))",
        "cat_b": "UC",
        "psi": "77"
    },
    {
        "ang": "80",
        "tip": "MR80-20",
        "part_no": "40290-20",
        "color": "Tan", "csscolor": "tip-tan",
        "tip_rate": "2",
        "pre_orf": "R20",
        "pre-orf_no": "40285-20",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.316",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.581",
        "r_max": "2.828",
        "vmd_s": "1355.4*Math.pow(pt,-0.2579)",
        "141_s": "4.0699*Math.log(pt)-8.9926",
        "200_s": "8.6163*Math.log(pt)-20.923",
        "600_s": "100-222.5*Math.pow(pt,(-0.4936))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.194",
        "orf_eff": "1.23",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "2.665",
        "p_max": "24",
        "r_min_b": "0.217",
        "r_max_b": "1.562",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1355.4*Math.pow(pt_b,-0.2579)",
        "141_b": "4.0699*Math.log(pt_b)-8.9926",
        "200_b": "8.6163*Math.log(pt_b)-20.923",
        "600_b": "100-222.5*Math.pow(pt_b,(-0.4936))",
        "cat_b": "UC",
        "psi": "107"
    },
    {
        "ang": "80",
        "tip": "MR80-25",
        "part_no": "40290-25",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "2.5",
        "pre_orf": "R25",
        "pre-orf_no": "40285-25",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.395",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.976",
        "r_max": "3.536",
        "vmd_s": "1284.3*Math.pow(pt,-0.222)",
        "141_s": "2.3423*Math.log(pt)-4.2566",
        "200_s": "5.9324*Math.log(pt)-13.923",
        "600_s": "100-170.38*Math.pow(pt,(-0.3918))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.208",
        "orf_eff": "1.32",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "3.601",
        "p_max": "18",
        "r_min_b": "0.233",
        "r_max_b": "1.679",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1284.3*Math.pow(pt_b,-0.222)",
        "141_b": "2.3423*Math.log(pt_b)-4.2566",
        "200_b": "5.9324*Math.log(pt_b)-13.923",
        "600_b": "100-170.38*Math.pow(pt_b,(-0.3918))",
        "cat_b": "UC",
        "psi": "144"
    },
    {
        "ang": "80",
        "tip": "MR80-30",
        "part_no": "40290-30",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "3",
        "pre_orf": "R30",
        "pre-orf_no": "40285-30",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.474",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "2.372",
        "r_max": "4.243",
        "vmd_s": "1218*Math.pow(pt,-0.2127)",
        "141_s": "2.3374*Math.log(pt)-4.3053",
        "200_s": "6.0114*Math.log(pt)-13.846",
        "600_s": "100-196.48*Math.pow(pt,(-0.4334))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.218",
        "orf_eff": "1.38",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "4.746",
        "p_max": "14",
        "r_min_b": "0.243",
        "r_max_b": "1.755",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1218*Math.pow(pt_b,-0.2127)",
        "141_b": "2.3374*Math.log(pt_b)-4.3053",
        "200_b": "6.0114*Math.log(pt_b)-13.846",
        "600_b": "100-196.48*Math.pow(pt_b,(-0.4334))",
        "cat_b": "UC",
        "psi": "190"
    },
    {
        "ang": "80",
        "tip": "MR80-40",
        "part_no": "40290-40",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "4",
        "pre_orf": "R40",
        "pre-orf_no": "40285-40",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.632",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "3.162",
        "r_max": "5.657",
        "vmd_s": "1239.8*Math.pow(pt,-0.2334)",
        "141_s": "1.9631*Math.log(pt)-2.6326",
        "200_s": "5.9363*Math.log(pt)-12.147",
        "600_s": "100-157.42*Math.pow(pt,(-0.3914))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.229",
        "orf_eff": "1.45",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "7.660",
        "p_max": "8",
        "r_min_b": "0.255",
        "r_max_b": "1.842",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1239.8*Math.pow(pt_b,-0.2334)",
        "141_b": "1.9631*Math.log(pt_b)-2.6326",
        "200_b": "5.9363*Math.log(pt_b)-12.147",
        "600_b": "100-157.42*Math.pow(pt_b,(-0.3914))",
        "cat_b": "UC",
        "psi": "307"
    },
    {
        "ang": "80",
        "tip": "DR80-005",
        "part_no": "40280-005",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "0.05",
        "pre_orf": "R005",
        "pre-orf_no": "40285-005",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.008",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.040",
        "r_max": "0.071",
        "vmd_s": "2422.3*Math.pow(pt,-0.6382)",
        "141_s": "27.554*Math.log(pt)-82.319",
        "200_s": "51.037*Math.log(pt)-146.97",
        "600_s": "100.0",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.008",
        "orf_eff": "0.05",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.001",
        "p_max": "65",
        "r_min_b": "0.009",
        "r_max_b": "0.064",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "2422.3*Math.pow(pt_b,-0.6382)",
        "141_b": "27.554*Math.log(pt_b)-82.319",
        "200_b": "51.037*Math.log(pt_b)-146.97",
        "600_b": "100.0",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "DR80-0067",
        "part_no": "40280-007",
        "color": "Pink", "csscolor": "tip-pink",
        "tip_rate": "0.067",
        "pre_orf": "R0067",
        "pre-orf_no": "40285-007",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.011",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.053",
        "r_max": "0.095",
        "vmd_s": "1650.6*Math.pow(pt,-0.494)",
        "141_s": "15.83*Math.log(pt)-45.109",
        "200_s": "32.458*Math.log(pt)-89.169",
        "600_s": "100",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.011",
        "orf_eff": "0.07",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.002",
        "p_max": "65",
        "r_min_b": "0.012",
        "r_max_b": "0.085",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1650.6*Math.pow(pt_b,-0.494)",
        "141_b": "15.83*Math.log(pt_b)-45.109",
        "200_b": "32.458*Math.log(pt_b)-89.169",
        "600_b": "100",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "DR80-01",
        "part_no": "40280-01",
        "color": "Orange", "csscolor": "tip-orange",
        "tip_rate": "0.1",
        "pre_orf": "RO1",
        "pre-orf_no": "40285-01",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.016",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.079",
        "r_max": "0.141",
        "vmd_s": "1409.8*Math.pow(pt,-0.4438)",
        "141_s": "13.739*Math.log(pt)-36.95",
        "200_s": "25.799*Math.log(pt)-66.483",
        "600_s": "100 - Math.max(-8.0349*pt*pt+33.4,0)",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.016",
        "orf_eff": "0.10",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.004",
        "p_max": "65",
        "r_min_b": "0.018",
        "r_max_b": "0.127",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1409.8*Math.pow(pt_b,-0.4438)",
        "141_b": "13.739*Math.log(pt_b)-36.95",
        "200_b": "25.799*Math.log(pt_b)-66.483",
        "600_b": "100-Math.max(-8.0349*pt_b*pt_b+33.4,0)",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "DR80-015",
        "part_no": "40280-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate": "0.15",
        "pre_orf": "R015",
        "pre-orf_no": "40285-015",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.024",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.119",
        "r_max": "0.212",
        "vmd_s": "1282.4*Math.pow(pt,-0.3298)",
        "141_s": "5.8813*Math.log(pt)-16.094",
        "200_s": "11.907*Math.log(pt)-31.46",
        "600_s": "100-461.17*Math.pow(pt,(-1.0451))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.024",
        "orf_eff": "0.15",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.009",
        "p_max": "64",
        "r_min_b": "0.026",
        "r_max_b": "0.190",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1282.4*Math.pow(pt_b,-0.3298)",
        "141_b": "5.8813*Math.log(pt_b)-16.094",
        "200_b": "11.907*Math.log(pt_b)-31.46",
        "600_b": "100-461.17*Math.pow(pt_b,(-1.0451))",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "80",
        "tip": "DR80-02",
        "part_no": "40280-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate": "0.2",
        "pre_orf": "R02",
        "pre-orf_no": "40285-02",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.032",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.158",
        "r_max": "0.283",
        "vmd_s": "1169.7*Math.pow(pt,-0.2781)",
        "141_s": "4.2837*Math.log(pt)-11.451",
        "200_s": "8.9278*Math.log(pt)-23.042",
        "600_s": "100-243.76*Math.pow(pt,(-0.7418))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.031",
        "orf_eff": "0.20",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.017",
        "p_max": "64",
        "r_min_b": "0.035",
        "r_max_b": "0.253",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1169.7*Math.pow(pt_b,-0.2781)",
        "141_b": "4.2837*Math.log(pt_b)-11.451",
        "200_b": "8.9278*Math.log(pt_b)-23.042",
        "600_b": "100-243.76*Math.pow(pt_b,(-0.7418))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "DR80-025",
        "part_no": "40280-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate": "0.25",
        "pre_orf": "R025",
        "pre-orf_no": "40285-025",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.040",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.198",
        "r_max": "0.354",
        "vmd_s": "1024.6*Math.pow(pt,-0.2356)",
        "141_s": "4.0993*Math.log(pt)-10.631",
        "200_s": "8.2093*Math.log(pt)-20.373",
        "600_s": "100-157.84*Math.pow(pt,(-0.5697))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.039",
        "orf_eff": "0.25",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.026",
        "p_max": "63",
        "r_min_b": "0.044",
        "r_max_b": "0.315",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1024.6*Math.pow(pt_b,-0.2356)",
        "141_b": "4.0993*Math.log(pt_b)-10.631",
        "200_b": "8.2093*Math.log(pt_b)-20.373",
        "600_b": "100-157.84*Math.pow(pt_b,(-0.5697))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "DR80-03",
        "part_no": "40280-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate": "0.3",
        "pre_orf": "R03",
        "pre-orf_no": "40285-03",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.047",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.237",
        "r_max": "0.424",
        "vmd_s": "1146.3*Math.pow(pt,-0.2555)",
        "141_s": "4.4861*Math.log(pt)-12.369",
        "200_s": "8.6604*Math.log(pt)-22.561",
        "600_s": "100-307.16*Math.pow(pt,(-0.7018))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.047",
        "orf_eff": "0.29",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.037",
        "p_max": "63",
        "r_min_b": "0.052",
        "r_max_b": "0.375",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1146.3*Math.pow(pt_b,-0.2555)",
        "141_b": "4.4861*Math.log(pt_b)-12.369",
        "200_b": "8.6604*Math.log(pt_b)-22.561",
        "600_b": "100-307.16*Math.pow(pt_b,(-0.7018))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "80",
        "tip": "DR80-04",
        "part_no": "40280-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate": "0.4",
        "pre_orf": "R04",
        "pre-orf_no": "40285-04",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.063",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.316",
        "r_max": "0.566",
        "vmd_s": "1226.7*Math.pow(pt,-0.2397)",
        "141_s": "3.1976*Math.log(pt)-8.8143",
        "200_s": "6.3827*Math.log(pt)-17.041",
        "600_s": "100-311.61*Math.pow(pt,(-0.6168))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.061",
        "orf_eff": "0.39",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.067",
        "p_max": "61",
        "r_min_b": "0.068",
        "r_max_b": "0.494",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1226.7*Math.pow(pt_b,-0.2397)",
        "141_b": "3.1976*Math.log(pt_b)-8.8143",
        "200_b": "6.3827*Math.log(pt_b)-17.041",
        "600_b": "100-311.61*Math.pow(pt_b,(-0.6168))",
        "cat_b": "UC",
        "psi": "43"
    },
    {
        "ang": "80",
        "tip": "DR80-05",
        "part_no": "40280-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate": "0.5",
        "pre_orf": "R05",
        "pre-orf_no": "40285-05",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.079",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.395",
        "r_max": "0.707",
        "vmd_s": "1234*Math.pow(pt,-0.2248)",
        "141_s": "2.5744*Math.log(pt)-7.1423",
        "200_s": "5.411*Math.log(pt)-14.577",
        "600_s": "100-296.92*Math.pow(pt,(-0.5583))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.075",
        "orf_eff": "0.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.104",
        "p_max": "59",
        "r_min_b": "0.084",
        "r_max_b": "0.607",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1234*Math.pow(pt_b,-0.2248)",
        "141_b": "2.5744*Math.log(pt_b)-7.1423",
        "200_b": "5.411*Math.log(pt_b)-14.577",
        "600_b": "100-296.92*Math.pow(pt_b,(-0.5583))",
        "cat_b": "UC",
        "psi": "44"
    },
    {
        "ang": "80",
        "tip": "DR80-06",
        "part_no": "40280-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate": "0.6",
        "pre_orf": "R06",
        "pre-orf_no": "40285-06",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.095",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.474",
        "r_max": "0.849",
        "vmd_s": "1161.2*Math.pow(pt,-0.1959)",
        "141_s": "1.971*Math.log(pt)-5.2908",
        "200_s": "5.7607*Math.log(pt)-15.893",
        "600_s": "100-205.85*Math.pow(pt,(-0.4235))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.088",
        "orf_eff": "0.56",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.150",
        "p_max": "57",
        "r_min_b": "0.099",
        "r_max_b": "0.713",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1161.2*Math.pow(pt_b,-0.1959)",
        "141_b": "1.971*Math.log(pt_b)-5.2908",
        "200_b": "5.7607*Math.log(pt_b)-15.893",
        "600_b": "100-205.85*Math.pow(pt_b,(-0.4235))",
        "cat_b": "UC",
        "psi": "46"
    },
    {
        "ang": "80",
        "tip": "DR80-08",
        "part_no": "40280-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate": "0.8",
        "pre_orf": "R08",
        "pre-orf_no": "40285-08",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.126",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.632",
        "r_max": "1.131",
        "vmd_s": "1222.7*Math.pow(pt,-0.2)",
        "141_s": "3.0933*Math.log(pt)-7.477",
        "200_s": "6.1172*Math.log(pt)-15.897",
        "600_s": "100-225.8*Math.pow(pt,(-0.4536))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.112",
        "orf_eff": "0.71",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.266",
        "p_max": "51",
        "r_min_b": "0.126",
        "r_max_b": "0.906",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1222.7*Math.pow(pt_b,-0.2)",
        "141_b": "3.0933*Math.log(pt_b)-7.477",
        "200_b": "6.1172*Math.log(pt_b)-15.897",
        "600_b": "100-225.8*Math.pow(pt_b,(-0.4536))",
        "cat_b": "UC",
        "psi": "51"
    },
    {
        "ang": "80",
        "tip": "DR80-10",
        "part_no": "40280-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate": "1",
        "pre_orf": "R010",
        "pre-orf_no": "40285-10",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.158",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.791",
        "r_max": "1.414",
        "vmd_s": "1083.2*Math.pow(pt,-0.1682)",
        "141_s": "2.8702*Math.log(pt)-5.38595",
        "200_s": "5.7744*Math.log(pt)-13.443",
        "600_s": "100-164.7*Math.pow(pt,(-0.3646))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.133",
        "orf_eff": "0.84",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.416",
        "p_max": "46",
        "r_min_b": "0.149",
        "r_max_b": "1.071",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1083.2*Math.pow(pt_b,-0.1682)",
        "141_b": "2.8702*Math.log(pt_b)-5.38595",
        "200_b": "5.7744*Math.log(pt_b)-13.443",
        "600_b": "100-164.7*Math.pow(pt_b,(-0.3646))",
        "cat_b": "UC",
        "psi": "57"
    },
    {
        "ang": "80",
        "tip": "DR80-125",
        "part_no": "40280-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate": "1.25",
        "pre_orf": "R12.5",
        "pre-orf_no": "40285-125",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.198",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.988",
        "r_max": "1.768",
        "vmd_s": "1096*Math.pow(pt,-0.1655)",
        "141_s": "2.5082*Math.log(pt)-4.5653",
        "200_s": "5.3588*Math.log(pt)-11.849",
        "600_s": "100-141.9*Math.pow(pt,(-0.3062))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.154",
        "orf_eff": "0.97",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.650",
        "p_max": "39",
        "r_min_b": "0.172",
        "r_max_b": "1.240",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1096*Math.pow(pt_b,-0.1655)",
        "141_b": "2.5082*Math.log(pt_b)-4.5653",
        "200_b": "5.3588*Math.log(pt_b)-11.849",
        "600_b": "100-141.9*Math.pow(pt_b,(-0.3062))",
        "cat_b": "UC",
        "psi": "66"
    },
    {
        "ang": "80",
        "tip": "DR80-15",
        "part_no": "40280-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate": "1.5",
        "pre_orf": "R15",
        "pre-orf_no": "40285-15",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.237",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.186",
        "r_max": "2.121",
        "vmd_s": "1175.8*Math.pow(pt,-0.1801)",
        "141_s": "2.0423*Math.log(pt)-4.2234",
        "200_s": "5.1061*Math.log(pt)-13.293",
        "600_s": "100-173.83*Math.pow(pt,(-0.3551))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.170",
        "orf_eff": "1.08",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.937",
        "p_max": "34",
        "r_min_b": "0.191",
        "r_max_b": "1.374",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1175.8*Math.pow(pt_b,-0.1801)",
        "141_b": "2.0423*Math.log(pt_b)-4.2234",
        "200_b": "5.1061*Math.log(pt_b)-13.293",
        "600_b": "100-173.83*Math.pow(pt_b,(-0.3551))",
        "cat_b": "UC",
        "psi": "77"
    },
    {
        "ang": "80",
        "tip": "DR80-20",
        "part_no": "40280-20",
        "color": "Tan", "csscolor": "tip-tan",
        "tip_rate": "2",
        "pre_orf": "R20",
        "pre-orf_no": "40285-20",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.316",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.581",
        "r_max": "2.828",
        "vmd_s": "1409.1*Math.pow(pt,-0.2375)",
        "141_s": "2.6422*Math.log(pt)-6.0899",
        "200_s": "6.1613*Math.log(pt)-15.976",
        "600_s": "100-230.43*Math.pow(pt,(-0.4511))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.194",
        "orf_eff": "1.23",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "2.665",
        "p_max": "24",
        "r_min_b": "0.217",
        "r_max_b": "1.562",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1409.1*Math.pow(pt_b,-0.2375)",
        "141_b": "2.6422*Math.log(pt_b)-6.0899",
        "200_b": "6.1613*Math.log(pt_b)-15.976",
        "600_b": "100-230.43*Math.pow(pt_b,(-0.4511))",
        "cat_b": "UC",
        "psi": "107"
    },
    {
        "ang": "80",
        "tip": "DR80-25",
        "part_no": "40280-25",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "2.5",
        "pre_orf": "R25",
        "pre-orf_no": "40285-25",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.395",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.976",
        "r_max": "3.536",
        "vmd_s": "1405.6*Math.pow(pt,-0.2234)",
        "141_s": "1.7473*Math.log(pt)-3.4415",
        "200_s": "4.7972*Math.log(pt)-12.126",
        "600_s": "100-227.7*Math.pow(pt,(-0.4232))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.208",
        "orf_eff": "1.32",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "3.601",
        "p_max": "18",
        "r_min_b": "0.233",
        "r_max_b": "1.679",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1405.6*Math.pow(pt_b,-0.2234)",
        "141_b": "1.7473*Math.log(pt_b)-3.4415",
        "200_b": "4.7972*Math.log(pt_b)-12.126",
        "600_b": "100-227.7*Math.pow(pt_b,(-0.4232))",
        "cat_b": "UC",
        "psi": "144"
    },
    {
        "ang": "80",
        "tip": "DR80-30",
        "part_no": "40280-30",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "3",
        "pre_orf": "R30",
        "pre-orf_no": "40285-30",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.474",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "2.372",
        "r_max": "4.243",
        "vmd_s": "1929.2*Math.pow(pt,-0.318)",
        "141_s": "1.6681*Math.log(pt)-3.5507",
        "200_s": "5.501*Math.log(pt)-14.654",
        "600_s": "100-326.69*Math.pow(pt,(-0.533))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.218",
        "orf_eff": "1.38",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "4.746",
        "p_max": "14",
        "r_min_b": "0.243",
        "r_max_b": "1.755",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1929.2*Math.pow(pt_b,-0.318)",
        "141_b": "1.6681*Math.log(pt_b)-3.5507",
        "200_b": "5.501*Math.log(pt_b)-14.654",
        "600_b": "100-326.69*Math.pow(pt_b,(-0.533))",
        "cat_b": "UC",
        "psi": "190"
    },
    {
        "ang": "110",
        "tip": "ER110-01",
        "part_no": "40281-01",
        "color": "Orange", "csscolor": "tip-orange",
        "tip_rate": "0.1",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.016",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.071",
        "r_max": "0.141",
        "vmd_s": "-22.058*Math.log(pt)+214.56",
        "141_s": "15.984*Math.log(pt)-3.2784",
        "200_s": "7.5739*Math.log(pt)+61.59",
        "600_s": "100.0",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.016",
        "orf_eff": "0.10",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.004",
        "p_max": "65",
        "r_min_b": "0.018",
        "r_max_b": "0.127",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-22.058*Math.log(pt_b)+214.56",
        "141_b": "15.984*Math.log(pt_b)-3.2784",
        "200_b": "7.5739*Math.log(pt_b)+61.59",
        "600_b": "100.0",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "110",
        "tip": "ER110-015",
        "part_no": "40281-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate": "0.15",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.024",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.106",
        "r_max": "0.212",
        "vmd_s": "-19.778*Math.log(pt)+211.87",
        "141_s": "16.246*Math.log(pt)-8.3676",
        "200_s": "9.5419*Math.log(pt)+48.306",
        "600_s": "100.0",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.024",
        "orf_eff": "0.15",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.009",
        "p_max": "64",
        "r_min_b": "0.026",
        "r_max_b": "0.190",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-19.778*Math.log(pt_b)+211.87",
        "141_b": "16.246*Math.log(pt_b)-8.3676",
        "200_b": "9.5419*Math.log(pt_b)+48.306",
        "600_b": "100.0",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "110",
        "tip": "ER110-02",
        "part_no": "40281-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate": "0.2",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.032",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.141",
        "r_max": "0.283",
        "vmd_s": "-32.021*Math.log(pt)+268.77",
        "141_s": "18.75*Math.log(pt)-24.294",
        "200_s": "15.989*Math.log(pt)+14.598",
        "600_s": "100-10.304*Math.pow(pt,(-1.038))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.031",
        "orf_eff": "0.20",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.017",
        "p_max": "64",
        "r_min_b": "0.035",
        "r_max_b": "0.253",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-32.021*Math.log(pt_b)+268.77",
        "141_b": "18.75*Math.log(pt_b)-24.294",
        "200_b": "15.989*Math.log(pt_b)+14.598",
        "600_b": "100-10.304*Math.pow(pt_b,(-1.038))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "ER110-025",
        "part_no": "40281-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate": "0.25",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.040",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.177",
        "r_max": "0.354",
        "vmd_s": "-19.01*Math.log(pt)+250.72",
        "141_s": "2.122*Math.log(pt)+21.986",
        "200_s": "5.4173*Math.log(pt)+37.533",
        "600_s": "100-0.0026*pt+0.0839",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.039",
        "orf_eff": "0.25",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.026",
        "p_max": "63",
        "r_min_b": "0.044",
        "r_max_b": "0.315",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-19.01*Math.log(pt_b)+250.72",
        "141_b": "2.122*Math.log(pt_b)+21.986",
        "200_b": "5.4173*Math.log(pt_b)+37.533",
        "600_b": "100-0.0026*pt_b+0.0839",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "ER110-03",
        "part_no": "40281-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate": "0.3",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.047",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.212",
        "r_max": "0.424",
        "vmd_s": "-35.567*Math.log(pt)+304.44",
        "141_s": "11.719*Math.log(pt)-8.5399",
        "200_s": "12.864*Math.log(pt)+12.491",
        "600_s": "100-0.0679*Math.pow(pt,(0.9049))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.047",
        "orf_eff": "0.29",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.037",
        "p_max": "63",
        "r_min_b": "0.052",
        "r_max_b": "0.375",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-35.567*Math.log(pt_b)+304.44",
        "141_b": "11.719*Math.log(pt_b)-8.5399",
        "200_b": "12.864*Math.log(pt_b)+12.491",
        "600_b": "100-0.0679*Math.pow(pt_b,(0.9049))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "ER110-04",
        "part_no": "40281-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate": "0.4",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.063",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.283",
        "r_max": "0.566",
        "vmd_s": "-37.35*Math.log(pt)+352.31",
        "141_s": "8.64*Math.log(pt)-7.5468",
        "200_s": "12.962*Math.log(pt)-2.5372",
        "600_s": "100-0.7668*Math.pow(pt,(0.4173))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.061",
        "orf_eff": "0.39",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.067",
        "p_max": "61",
        "r_min_b": "0.068",
        "r_max_b": "0.494",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-37.35*Math.log(pt_b)+352.31",
        "141_b": "8.64*Math.log(pt_b)-7.5468",
        "200_b": "12.962*Math.log(pt_b)-2.5372",
        "600_b": "100-0.7668*Math.pow(pt_b,(0.4173))",
        "cat_b": "UC",
        "psi": "43"
    },
    {
        "ang": "110",
        "tip": "ER110-05",
        "part_no": "40281-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate": "0.5",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.079",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.354",
        "r_max": "0.707",
        "vmd_s": "482.05*Math.pow(pt,(-0.2223))",
        "141_s": "11.275*Math.log(pt)-15.896",
        "200_s": "14.499*Math.log(pt)-7.8389",
        "600_s": "100-5.1219*Math.pow(pt,(-0.0273))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.075",
        "orf_eff": "0.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.104",
        "p_max": "59",
        "r_min_b": "0.084",
        "r_max_b": "0.607",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "482.05*Math.pow(pt_b,(-0.2223))",
        "141_b": "11.275*Math.log(pt_b)-15.896",
        "200_b": "14.499*Math.log(pt_b)-7.8389",
        "600_b": "100-5.1219*Math.pow(pt_b,(-0.0273))",
        "cat_b": "UC",
        "psi": "44"
    },
    {
        "ang": "110",
        "tip": "ER110-06",
        "part_no": "40281-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate": "0.6",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.095",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.424",
        "r_max": "0.849",
        "vmd_s": "-51.529*Math.log(pt)+436.31",
        "141_s": "9.1727*Math.log(pt)-13.564",
        "200_s": "13.632*Math.log(pt)-12.66",
        "600_s": "100-7.1048*Math.pow(pt,(-0.0683))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.088",
        "orf_eff": "0.56",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.150",
        "p_max": "57",
        "r_min_b": "0.099",
        "r_max_b": "0.713",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-51.529*Math.log(pt_b)+436.31",
        "141_b": "9.1727*Math.log(pt_b)-13.564",
        "200_b": "13.632*Math.log(pt_b)-12.66",
        "600_b": "100-7.1048*Math.pow(pt_b,(-0.0683))",
        "cat_b": "UC",
        "psi": "46"
    },
    {
        "ang": "110",
        "tip": "ER110-08",
        "part_no": "40281-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate": "0.8",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.126",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.566",
        "r_max": "1.131",
        "vmd_s": "-90.342*Math.log(pt)+597.65",
        "141_s": "8.7318*Math.log(pt)-12.356",
        "200_s": "14.879*Math.log(pt)-19.045",
        "600_s": "100-101.11*Math.pow(pt,(-0.7922))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.112",
        "orf_eff": "0.71",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.266",
        "p_max": "51",
        "r_min_b": "0.126",
        "r_max_b": "0.906",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-90.342*Math.log(pt_b)+597.65",
        "141_b": "8.7318*Math.log(pt_b)-12.356",
        "200_b": "14.879*Math.log(pt_b)-19.045",
        "600_b": "100-101.11*Math.pow(pt_b,(-0.7922))",
        "cat_b": "UC",
        "psi": "51"
    },
    {
        "ang": "110",
        "tip": "ER110-10",
        "part_no": "40281-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate": "1",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.158",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.707",
        "r_max": "1.414",
        "vmd_s": "-92.523*Math.log(pt)+639.32",
        "141_s": "9.4459*Math.log(pt)-18.142",
        "200_s": "12.443*Math.log(pt)-13.276",
        "600_s": "100-64.95*Math.pow(pt,(-0.5631))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.200",
        "cv_eff": "0.108",
        "orf_eff": "0.84",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.624",
        "p_max": "46",
        "r_min_b": "0.182",
        "r_max_b": "1.312",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-92.523*Math.log(pt_b)+639.32",
        "141_b": "9.4459*Math.log(pt_b)-18.142",
        "200_b": "12.443*Math.log(pt_b)-13.276",
        "600_b": "100-64.95*Math.pow(pt_b,(-0.5631))",
        "cat_b": "UC",
        "psi": "57"
    },
    {
        "ang": "110",
        "tip": "ER110-125",
        "part_no": "40281-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate": "1.25",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.198",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.884",
        "r_max": "1.768",
        "vmd_s": "-92.412*Math.log(pt)+697.78",
        "141_s": "3.9753*Math.log(pt)-3.279",
        "200_s": "4.7088*Math.log(pt)+2.2079",
        "600_s": "100-198.6*Math.pow(pt,(-0.6268))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.154",
        "orf_eff": "0.97",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.650",
        "p_max": "39",
        "r_min_b": "0.172",
        "r_max_b": "1.240",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-92.412*Math.log(pt_b)+697.78",
        "141_b": "3.9753*Math.log(pt_b)-3.279",
        "200_b": "4.7088*Math.log(pt_b)+2.2079",
        "600_b": "100-198.6*Math.pow(pt_b,(-0.6268))",
        "cat_b": "UC",
        "psi": "66"
    },
    {
        "ang": "110",
        "tip": "ER110-15",
        "part_no": "40281-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate": "1.5",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.237",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.061",
        "r_max": "2.121",
        "vmd_s": "-97.899*Math.log(pt)+730.78",
        "141_s": "4.8929*Math.log(pt)-6.1773",
        "200_s": "5.906*Math.log(pt)-2.3276",
        "600_s": "100-197.64*Math.pow(pt,(-0.5694))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.170",
        "orf_eff": "1.08",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.937",
        "p_max": "34",
        "r_min_b": "0.191",
        "r_max_b": "1.374",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-97.899*Math.log(pt_b)+730.78",
        "141_b": "4.8929*Math.log(pt_b)-6.1773",
        "200_b": "5.906*Math.log(pt_b)-2.3276",
        "600_b": "100-197.64*Math.pow(pt_b,(-0.5694))",
        "cat_b": "UC",
        "psi": "77"
    },
    {
        "ang": "110",
        "tip": "ER110-20",
        "part_no": "40281-20",
        "color": "Tan", "csscolor": "tip-tan",
        "tip_rate": "2",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.316",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.414",
        "r_max": "2.828",
        "vmd_s": "-107.26*Math.log(pt)+818.14",
        "141_s": "3.0239*Math.log(pt)-2.4897",
        "200_s": "5.6703*Math.log(pt)-6.1382",
        "600_s": "100-193.73*Math.pow(pt,(-0.4923))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.194",
        "orf_eff": "1.23",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "2.665",
        "p_max": "24",
        "r_min_b": "0.217",
        "r_max_b": "1.562",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-107.26*Math.log(pt_b)+818.14",
        "141_b": "3.0239*Math.log(pt_b)-2.4897",
        "200_b": "5.6703*Math.log(pt_b)-6.1382",
        "600_b": "100-193.73*Math.pow(pt_b,(-0.4923))",
        "cat_b": "UC",
        "psi": "107"
    },
    {
        "ang": "110",
        "tip": "ER110-25",
        "part_no": "40281-25",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "2.5",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.395",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.768",
        "r_max": "3.536",
        "vmd_s": "-105.24*Math.log(pt)+810.69",
        "141_s": "1.5863*Math.log(pt)+1.5158",
        "200_s": "3.8459*Math.log(pt)-1.1911",
        "600_s": "100-311.16*Math.pow(pt,(-0.6388))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.208",
        "orf_eff": "1.32",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "3.601",
        "p_max": "18",
        "r_min_b": "0.233",
        "r_max_b": "1.679",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-105.24*Math.log(pt_b)+810.69",
        "141_b": "1.5863*Math.log(pt_b)+1.5158",
        "200_b": "3.8459*Math.log(pt_b)-1.1911",
        "600_b": "100-311.16*Math.pow(pt_b,(-0.6388))",
        "cat_b": "UC",
        "psi": "144"
    },
    {
        "ang": "110",
        "tip": "ER110-30",
        "part_no": "40281-30",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "3",
        "pre_orf": "N/A",
        "pre-orf_no": "N/A",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.474",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "2.121",
        "r_max": "4.243",
        "vmd_s": "-100.71*Math.log(pt)+808.61",
        "141_s": "3.2967*Math.log(pt)-4.9903",
        "200_s": "5.4969*Math.log(pt)-7.6025",
        "600_s": "100-139.27*Math.pow(pt,(-0.3753))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.218",
        "orf_eff": "1.38",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "4.746",
        "p_max": "14",
        "r_min_b": "0.243",
        "r_max_b": "1.755",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-100.71*Math.log(pt_b)+808.61",
        "141_b": "3.2967*Math.log(pt_b)-4.9903",
        "200_b": "5.4969*Math.log(pt_b)-7.6025",
        "600_b": "100-139.27*Math.pow(pt_b,(-0.3753))",
        "cat_b": "UC",
        "psi": "190"
    },
    {
        "ang": "110",
        "tip": "SR110-015",
        "part_no": "40287-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate": "0.15",
        "pre_orf": "R02",
        "pre-orf_no": "40285-02",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.024",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.119",
        "r_max": "0.212",
        "vmd_s": "-54.823*Math.log(pt)+401.72",
        "141_s": "15.162*Math.log(pt)-27.585",
        "200_s": "20.542*Math.log(pt)-25.167",
        "600_s": "100-3.2595*Math.pow(pt,(-0.0958))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.024",
        "orf_eff": "0.15",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.009",
        "p_max": "64",
        "r_min_b": "0.026",
        "r_max_b": "0.190",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-54.823*Math.log(pt_b)+401.72",
        "141_b": "15.162*Math.log(pt_b)-27.585",
        "200_b": "20.542*Math.log(pt_b)-25.167",
        "600_b": "100-3.2595*Math.pow(pt_b,(-0.0958))",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "110",
        "tip": "SR110-02",
        "part_no": "40287-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate": "0.2",
        "pre_orf": "R02",
        "pre-orf_no": "40285-02",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.032",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.158",
        "r_max": "0.283",
        "vmd_s": "-44.861*Math.log(pt)+371.52",
        "141_s": "11.698*Math.log(pt)-17.099",
        "200_s": "16.71*Math.log(pt)-13.315",
        "600_s": "100-1.1366*Math.pow(pt,(-0.0909))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.031",
        "orf_eff": "0.20",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.017",
        "p_max": "64",
        "r_min_b": "0.035",
        "r_max_b": "0.253",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-44.861*Math.log(pt_b)+371.52",
        "141_b": "11.698*Math.log(pt_b)-17.099",
        "200_b": "16.71*Math.log(pt_b)-13.315",
        "600_b": "100-1.1366*Math.pow(pt_b,(-0.0909))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "SR110-025",
        "part_no": "40287-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate": "0.25",
        "pre_orf": "R025",
        "pre-orf_no": "40285-025",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.040",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.198",
        "r_max": "0.354",
        "vmd_s": "-47.7371*Math.log(pt)+398.07",
        "141_s": "10.531*Math.log(pt)-16.166",
        "200_s": "15.982*Math.log(pt)-16.044",
        "600_s": "100-2.9027*Math.pow(pt,(-0.1444))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.039",
        "orf_eff": "0.25",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.026",
        "p_max": "63",
        "r_min_b": "0.044",
        "r_max_b": "0.315",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-47.7371*Math.log(pt_b)+398.07",
        "141_b": "10.531*Math.log(pt_b)-16.166",
        "200_b": "15.982*Math.log(pt_b)-16.044",
        "600_b": "100-2.9027*Math.pow(pt_b,(-0.1444))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "SR110-03",
        "part_no": "40287-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate": "0.3",
        "pre_orf": "R03",
        "pre-orf_no": "40285-03",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.047",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.237",
        "r_max": "0.424",
        "vmd_s": "-85.56*Math.log(pt)+594.45",
        "141_s": "11.132*Math.log(pt)-26.392",
        "200_s": "18.728*Math.log(pt)-40.05",
        "600_s": "100-123.39*Math.pow(pt,(-0.9246))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.047",
        "orf_eff": "0.29",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.037",
        "p_max": "63",
        "r_min_b": "0.052",
        "r_max_b": "0.375",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-85.56*Math.log(pt_b)+594.45",
        "141_b": "11.132*Math.log(pt_b)-26.392",
        "200_b": "18.728*Math.log(pt_b)-40.05",
        "600_b": "100-123.39*Math.pow(pt_b,(-0.9246))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "SR110-04",
        "part_no": "40287-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate": "0.4",
        "pre_orf": "R04",
        "pre-orf_no": "40285-04",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.063",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.316",
        "r_max": "0.566",
        "vmd_s": "-87.668*Math.log(pt)+611.84",
        "141_s": "9.2354*Math.log(pt)-20.374",
        "200_s": "16.644*Math.log(pt)-34.14",
        "600_s": "100-103.18*Math.pow(pt,(-0.8256))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.061",
        "orf_eff": "0.39",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.067",
        "p_max": "61",
        "r_min_b": "0.068",
        "r_max_b": "0.494",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-87.668*Math.log(pt_b)+611.84",
        "141_b": "9.2354*Math.log(pt_b)-20.374",
        "200_b": "16.644*Math.log(pt_b)-34.14",
        "600_b": "100-103.18*Math.pow(pt_b,(-0.8256))",
        "cat_b": "UC",
        "psi": "43"
    },
    {
        "ang": "110",
        "tip": "SR110-05",
        "part_no": "40287-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate": "0.5",
        "pre_orf": "R05",
        "pre-orf_no": "40285-05",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.079",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.395",
        "r_max": "0.707",
        "vmd_s": "-115.8*Math.log(pt)+749.34",
        "141_s": "9.2994*Math.log(pt)-23.297",
        "200_s": "17.1*Math.log(pt)-40.879",
        "600_s": "100-332.29*Math.pow(pt,(-1.0665))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.075",
        "orf_eff": "0.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.104",
        "p_max": "59",
        "r_min_b": "0.084",
        "r_max_b": "0.607",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-115.8*Math.log(pt_b)+749.34",
        "141_b": "9.2994*Math.log(pt_b)-23.297",
        "200_b": "17.1*Math.log(pt_b)-40.879",
        "600_b": "100-332.29*Math.pow(pt_b,(-1.0665))",
        "cat_b": "UC",
        "psi": "44"
    },
    {
        "ang": "110",
        "tip": "SR110-06",
        "part_no": "40287-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate": "0.6",
        "pre_orf": "R06",
        "pre-orf_no": "40285-06",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.095",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.474",
        "r_max": "0.849",
        "vmd_s": "-155.26*Math.log(pt)+944.05",
        "141_s": "8.5565*Math.log(pt)-23.15",
        "200_s": "16.116*Math.log(pt)-42.137",
        "600_s": "100-1228.9*Math.pow(pt,(-1.2723))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.088",
        "orf_eff": "0.56",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.150",
        "p_max": "57",
        "r_min_b": "0.099",
        "r_max_b": "0.713",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-155.26*Math.log(pt_b)+944.05",
        "141_b": "8.5565*Math.log(pt_b)-23.15",
        "200_b": "16.116*Math.log(pt_b)-42.137",
        "600_b": "100-1228.9*Math.pow(pt_b,(-1.2723))",
        "cat_b": "UC",
        "psi": "46"
    },
    {
        "ang": "110",
        "tip": "SR110-08",
        "part_no": "40287-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate": "0.8",
        "pre_orf": "R08",
        "pre-orf_no": "40285-08",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.126",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.632",
        "r_max": "1.131",
        "vmd_s": "-153.89*Math.log(pt)+976.15",
        "141_s": "5.738*Math.log(pt)-13.743",
        "200_s": "8.1024*Math.log(pt)-15.081",
        "600_s": "100-652.29*Math.pow(pt,(-0.8742))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.112",
        "orf_eff": "0.71",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.266",
        "p_max": "51",
        "r_min_b": "0.126",
        "r_max_b": "0.906",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-153.89*Math.log(pt_b)+976.15",
        "141_b": "5.738*Math.log(pt_b)-13.743",
        "200_b": "8.1024*Math.log(pt_b)-15.081",
        "600_b": "100-652.29*Math.pow(pt_b,(-0.8742))",
        "cat_b": "UC",
        "psi": "51"
    },
    {
        "ang": "110",
        "tip": "SR110-10",
        "part_no": "40287-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate": "1",
        "pre_orf": "R010",
        "pre-orf_no": "40285-10",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.158",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.791",
        "r_max": "1.414",
        "vmd_s": "-162.26*Math.log(pt)+1022.3",
        "141_s": "4.6649*Math.log(pt)-9.8077",
        "200_s": "7.9985*Math.log(pt)-15.733",
        "600_s": "100-615.32*Math.pow(pt,(-0.8211))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.133",
        "orf_eff": "0.84",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.416",
        "p_max": "46",
        "r_min_b": "0.149",
        "r_max_b": "1.071",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-162.26*Math.log(pt_b)+1022.3",
        "141_b": "4.6649*Math.log(pt_b)-9.8077",
        "200_b": "7.9985*Math.log(pt_b)-15.733",
        "600_b": "100-615.32*Math.pow(pt_b,(-0.8211))",
        "cat_b": "UC",
        "psi": "57"
    },
    {
        "ang": "110",
        "tip": "SR110-125",
        "part_no": "40287-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate": "1.25",
        "pre_orf": "R12.5",
        "pre-orf_no": "40285-125",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.198",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.988",
        "r_max": "1.768",
        "vmd_s": "-166.94*Math.log(pt)+1038.6",
        "141_s": "3.3982*Math.log(pt)-6.6623",
        "200_s": "8.9653*Math.log(pt)-20.546",
        "600_s": "100-520.02*Math.pow(pt,(-0.7691))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.154",
        "orf_eff": "0.97",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.650",
        "p_max": "39",
        "r_min_b": "0.172",
        "r_max_b": "1.240",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-166.94*Math.log(pt_b)+1038.6",
        "141_b": "3.3982*Math.log(pt_b)-6.6623",
        "200_b": "8.9653*Math.log(pt_b)-20.546",
        "600_b": "100-520.02*Math.pow(pt_b,(-0.7691))",
        "cat_b": "UC",
        "psi": "66"
    },
    {
        "ang": "110",
        "tip": "SR110-15",
        "part_no": "40287-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate": "1.5",
        "pre_orf": "R15",
        "pre-orf_no": "40285-15",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.237",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.186",
        "r_max": "2.121",
        "vmd_s": "-148.22*Math.log(pt)+1042.4",
        "141_s": "2.9323*Math.log(pt)-5.2204",
        "200_s": "6.1866*Math.log(pt)-13.055",
        "600_s": "100-375.19*Math.pow(pt,(-0.5963))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.170",
        "orf_eff": "1.08",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.937",
        "p_max": "34",
        "r_min_b": "0.191",
        "r_max_b": "1.374",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-148.22*Math.log(pt_b)+1042.4",
        "141_b": "2.9323*Math.log(pt_b)-5.2204",
        "200_b": "6.1866*Math.log(pt_b)-13.055",
        "600_b": "100-375.19*Math.pow(pt_b,(-0.5963))",
        "cat_b": "UC",
        "psi": "77"
    },
    {
        "ang": "110",
        "tip": "SR110-20",
        "part_no": "40287-20",
        "color": "Tan", "csscolor": "tip-tan",
        "tip_rate": "2",
        "pre_orf": "R25",
        "pre-orf_no": "40285-25",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.316",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.581",
        "r_max": "2.828",
        "vmd_s": "-166.94*Math.log(pt)+1038.6",
        "141_s": "2.8751*Math.log(pt)-4.1109",
        "200_s": "6.33848*Math.log(pt)-11.845",
        "600_s": "100-376.75*Math.pow(pt,(-0.6217))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.194",
        "orf_eff": "1.23",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "2.665",
        "p_max": "24",
        "r_min_b": "0.217",
        "r_max_b": "1.562",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-166.94*Math.log(pt_b)+1038.6",
        "141_b": "2.8751*Math.log(pt_b)-4.1109",
        "200_b": "6.33848*Math.log(pt_b)-11.845",
        "600_b": "100-376.75*Math.pow(pt_b,(-0.6217))",
        "cat_b": "UC",
        "psi": "107"
    },
    {
        "ang": "110",
        "tip": "SR110-25",
        "part_no": "40287-25",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate": "2.5",
        "pre_orf": "R40",
        "pre-orf_no": "40285-40",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.395",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.976",
        "r_max": "3.536",
        "vmd_s": "-148.22*Math.log(pt)+1042.4",
        "141_s": "2.818*Math.log(pt)-3.9013",
        "200_s": "5.4924*Math.log(pt)-8.9327",
        "600_s": "100-243.64*Math.pow(pt,-0.5033)",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.208",
        "orf_eff": "1.32",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "3.601",
        "p_max": "18",
        "r_min_b": "0.233",
        "r_max_b": "1.679",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-148.22*Math.log(pt_b)+1042.4",
        "141_b": "2.818*Math.log(pt_b)-3.9013",
        "200_b": "5.4924*Math.log(pt_b)-8.9327",
        "600_b": "100-243.64*Math.pow(pt_b,-0.5033)",
        "cat_b": "UC",
        "psi": "144"
    },
    {
        "ang": "110",
        "tip": "MR110-015",
        "part_no": "40291-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate": "0.15",
        "pre_orf": "R015",
        "pre-orf_no": "40285-015",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.024",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.119",
        "r_max": "0.212",
        "vmd_s": "1852.7*Math.pow(pt,(-0.5149))",
        "141_s": "16.71*Math.log(pt)-45.577",
        "200_s": "28.01*Math.log(pt)-73.222",
        "600_s": "100-35307*Math.pow(pt,(-2.5749))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.024",
        "orf_eff": "0.15",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.009",
        "p_max": "64",
        "r_min_b": "0.026",
        "r_max_b": "0.190",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1852.7*Math.pow(pt_b,(-0.5149))",
        "141_b": "16.71*Math.log(pt_b)-45.577",
        "200_b": "28.01*Math.log(pt_b)-73.222",
        "600_b": "100-35307*Math.pow(pt_b,(-2.5749))",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "110",
        "tip": "MR110-02",
        "part_no": "40291-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate": "0.2",
        "pre_orf": "R02",
        "pre-orf_no": "40285-02",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.032",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.158",
        "r_max": "0.283",
        "vmd_s": "1332.4*Math.pow(pt,(-0.4238))",
        "141_s": "13.714*Math.log(pt)-35.104",
        "200_s": "22.555*Math.log(pt)-53.551",
        "600_s": "100-281.54*Math.pow(pt,(-1.2053))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.031",
        "orf_eff": "0.20",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.017",
        "p_max": "64",
        "r_min_b": "0.035",
        "r_max_b": "0.253",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1332.4*Math.pow(pt_b,(-0.4238))",
        "141_b": "13.714*Math.log(pt_b)-35.104",
        "200_b": "22.555*Math.log(pt_b)-53.551",
        "600_b": "100-281.54*Math.pow(pt_b,(-1.2053))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "MR110-025",
        "part_no": "40291-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate": "0.25",
        "pre_orf": "R025",
        "pre-orf_no": "40285-025",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.040",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.198",
        "r_max": "0.354",
        "vmd_s": "-105.56*Math.log(pt)+709.13",
        "141_s": "9.383*Math.log(pt)-23.244",
        "200_s": "16.094*Math.log(pt)-37.187",
        "600_s": "100-475.87*Math.pow(pt,(-1.1541))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.039",
        "orf_eff": "0.25",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.026",
        "p_max": "63",
        "r_min_b": "0.044",
        "r_max_b": "0.315",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-105.56*Math.log(pt_b)+709.13",
        "141_b": "9.383*Math.log(pt_b)-23.244",
        "200_b": "16.094*Math.log(pt_b)-37.187",
        "600_b": "100-475.87*Math.pow(pt_b,(-1.1541))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "MR110-03",
        "part_no": "40291-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate": "0.3",
        "pre_orf": "R03",
        "pre-orf_no": "40285-03",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.047",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.237",
        "r_max": "0.424",
        "vmd_s": "-120.65*Math.log(pt)+804.82",
        "141_s": "7.6662*Math.log(pt)-19.748",
        "200_s": "13.982*Math.log(pt)-34.376",
        "600_s": "100-1014.4*Math.pow(pt,(-1.2675))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.047",
        "orf_eff": "0.29",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.037",
        "p_max": "63",
        "r_min_b": "0.052",
        "r_max_b": "0.375",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-120.65*Math.log(pt_b)+804.82",
        "141_b": "7.6662*Math.log(pt_b)-19.748",
        "200_b": "13.982*Math.log(pt_b)-34.376",
        "600_b": "100-1014.4*Math.pow(pt_b,(-1.2675))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "MR110-04",
        "part_no": "40291-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate": "0.4",
        "pre_orf": "R04",
        "pre-orf_no": "40285-04",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.063",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.316",
        "r_max": "0.566",
        "vmd_s": "-136.47*Math.log(pt)+880.15",
        "141_s": "6.4957*Math.log(pt)-17.209",
        "200_s": "13.293*Math.log(pt)-34.116",
        "600_s": "100-1519.7*Math.pow(pt,(-1.345))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.061",
        "orf_eff": "0.39",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.067",
        "p_max": "61",
        "r_min_b": "0.068",
        "r_max_b": "0.494",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-136.47*Math.log(pt_b)+880.15",
        "141_b": "6.4957*Math.log(pt_b)-17.209",
        "200_b": "13.293*Math.log(pt_b)-34.116",
        "600_b": "100-1519.7*Math.pow(pt_b,(-1.345))",
        "cat_b": "UC",
        "psi": "43"
    },
    {
        "ang": "110",
        "tip": "MR110-05",
        "part_no": "40291-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate": "0.5",
        "pre_orf": "R05",
        "pre-orf_no": "40285-05",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.079",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.395",
        "r_max": "0.707",
        "vmd_s": "-144.67*Math.log(pt)+978.24",
        "141_s": "4.705*Math.log(pt)-12.677",
        "200_s": "9.4188*Math.log(pt)-24.409",
        "600_s": "100-553.84*Math.pow(pt,(-0.8757))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.075",
        "orf_eff": "0.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.104",
        "p_max": "59",
        "r_min_b": "0.084",
        "r_max_b": "0.607",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-144.67*Math.log(pt_b)+978.24",
        "141_b": "4.705*Math.log(pt_b)-12.677",
        "200_b": "9.4188*Math.log(pt_b)-24.409",
        "600_b": "100-553.84*Math.pow(pt_b,(-0.8757))",
        "cat_b": "UC",
        "psi": "44"
    },
    {
        "ang": "110",
        "tip": "MR110-06",
        "part_no": "40291-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate": "0.6",
        "pre_orf": "R06",
        "pre-orf_no": "40285-06",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.095",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.474",
        "r_max": "0.849",
        "vmd_s": "-115.58*Math.log(pt)+900.53",
        "141_s": "2.5469*Math.log(pt)-5.5518",
        "200_s": "5.5671*Math.log(pt)-11.983",
        "600_s": "100-449.96*Math.pow(pt,(-0.7727))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.088",
        "orf_eff": "0.56",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.150",
        "p_max": "57",
        "r_min_b": "0.099",
        "r_max_b": "0.713",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-115.58*Math.log(pt_b)+900.53",
        "141_b": "2.5469*Math.log(pt_b)-5.5518",
        "200_b": "5.5671*Math.log(pt_b)-11.983",
        "600_b": "100-449.96*Math.pow(pt_b,(-0.7727))",
        "cat_b": "UC",
        "psi": "46"
    },
    {
        "ang": "110",
        "tip": "MR110-08",
        "part_no": "40291-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate": "0.8",
        "pre_orf": "R08",
        "pre-orf_no": "40285-08",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.126",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.632",
        "r_max": "1.131",
        "vmd_s": "-165.74*Math.log(pt)+1094.8",
        "141_s": "3.4006*Math.log(pt)-7.338",
        "200_s": "6.4122*Math.log(pt)-13.549",
        "600_s": "100-468.08*Math.pow(pt,(-0.6744))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.112",
        "orf_eff": "0.71",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.266",
        "p_max": "51",
        "r_min_b": "0.126",
        "r_max_b": "0.906",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-165.74*Math.log(pt_b)+1094.8",
        "141_b": "3.4006*Math.log(pt_b)-7.338",
        "200_b": "6.4122*Math.log(pt_b)-13.549",
        "600_b": "100-468.08*Math.pow(pt_b,(-0.6744))",
        "cat_b": "UC",
        "psi": "51"
    },
    {
        "ang": "110",
        "tip": "MR110-10",
        "part_no": "40291-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate": "1",
        "pre_orf": "R010",
        "pre-orf_no": "40285-10",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.158",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.791",
        "r_max": "1.414",
        "vmd_s": "-159.2*Math.log(pt)+1064.8",
        "141_s": "2.9421*Math.log(pt)-5.9232",
        "200_s": "5.7355*Math.log(pt)-11.968",
        "600_s": "100-291.88*Math.pow(pt,(-0.5354))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.133",
        "orf_eff": "0.84",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.416",
        "p_max": "46",
        "r_min_b": "0.149",
        "r_max_b": "1.071",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-159.2*Math.log(pt_b)+1064.8",
        "141_b": "2.9421*Math.log(pt_b)-5.9232",
        "200_b": "5.7355*Math.log(pt_b)-11.968",
        "600_b": "100-291.88*Math.pow(pt_b,(-0.5354))",
        "cat_b": "UC",
        "psi": "57"
    },
    {
        "ang": "110",
        "tip": "MR110-125",
        "part_no": "40291-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate": "1.25",
        "pre_orf": "R12.5",
        "pre-orf_no": "40285-125",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.198",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.988",
        "r_max": "1.768",
        "vmd_s": "-161.51*Math.log(pt)+1167",
        "141_s": "2.0325*Math.log(pt)-3.0206",
        "200_s": "5.2696*Math.log(pt)-12.326",
        "600_s": "100-272.17*Math.pow(pt,(-0.4417))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.154",
        "orf_eff": "0.97",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.650",
        "p_max": "39",
        "r_min_b": "0.172",
        "r_max_b": "1.240",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-161.51*Math.log(pt_b)+1167",
        "141_b": "2.0325*Math.log(pt_b)-3.0206",
        "200_b": "5.2696*Math.log(pt_b)-12.326",
        "600_b": "100-272.17*Math.pow(pt_b,(-0.4417))",
        "cat_b": "UC",
        "psi": "66"
    },
    {
        "ang": "110",
        "tip": "MR110-15",
        "part_no": "40291-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate": "1.5",
        "pre_orf": "R15",
        "pre-orf_no": "40285-15",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.237",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.186",
        "r_max": "2.121",
        "vmd_s": "-117.43*Math.log(pt)+1007.3",
        "141_s": "0.6964*Math.log(pt)+1.9128",
        "200_s": "3.0124*Math.log(pt)-3.3809",
        "600_s": "100-168.51*Math.pow(pt,(-0.3055))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.170",
        "orf_eff": "1.08",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.937",
        "p_max": "34",
        "r_min_b": "0.191",
        "r_max_b": "1.374",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-117.43*Math.log(pt_b)+1007.3",
        "141_b": "0.6964*Math.log(pt_b)+1.9128",
        "200_b": "3.0124*Math.log(pt_b)-3.3809",
        "600_b": "100-168.51*Math.pow(pt_b,(-0.3055))",
        "cat_b": "UC",
        "psi": "77"
    },
    {
        "ang": "110",
        "tip": "MR110-20",
        "part_no": "40291-20",
        "color": "Tan", "csscolor": "tip-tan",
        "tip_rate": "2",
        "pre_orf": "R20",
        "pre-orf_no": "40285-20",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.316",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.581",
        "r_max": "2.828",
        "vmd_s": "-125.46*Math.log(pt)+1020",
        "141_s": "2.1886*Math.log(pt)-3.0265",
        "200_s": "4.4531*Math.log(pt)-8.1077",
        "600_s": "100-186.13*Math.pow(pt,(-0.3442))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.194",
        "orf_eff": "1.23",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "2.665",
        "p_max": "24",
        "r_min_b": "0.217",
        "r_max_b": "1.562",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-125.46*Math.log(pt_b)+1020",
        "141_b": "2.1886*Math.log(pt_b)-3.0265",
        "200_b": "4.4531*Math.log(pt_b)-8.1077",
        "600_b": "100-186.13*Math.pow(pt_b,(-0.3442))",
        "cat_b": "UC",
        "psi": "107"
    },
    {
        "ang": "110",
        "tip": "DR110-015",
        "part_no": "40286-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate": "0.15",
        "pre_orf": "R015",
        "pre-orf_no": "40285-015",
        "screen_no": "100 Mesh (#40251-00)",
        "screen": "100/Green",
        "cv_tip": "0.024",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.119",
        "r_max": "0.212",
        "vmd_s": "1351.7*Math.pow(pt,-(0.3839))",
        "141_s": "9.8853*Math.log(pt)-26.663",
        "200_s": "17.93*Math.log(pt)-45.923",
        "600_s": "100-303.51*Math.pow(pt,(-1.0582))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.024",
        "orf_eff": "0.15",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.009",
        "p_max": "64",
        "r_min_b": "0.026",
        "r_max_b": "0.190",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "1351.7*Math.pow(pt_b,-(0.3839))",
        "141_b": "9.8853*Math.log(pt_b)-26.663",
        "200_b": "17.93*Math.log(pt_b)-45.923",
        "600_b": "100-303.51*Math.pow(pt_b,(-1.0582))",
        "cat_b": "UC",
        "psi": "40"
    },
    {
        "ang": "110",
        "tip": "DR110-02",
        "part_no": "40286-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate": "0.2",
        "pre_orf": "R02",
        "pre-orf_no": "40285-02",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.032",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.158",
        "r_max": "0.283",
        "vmd_s": "-136.62*Math.log(pt)+895.69",
        "141_s": "6.5086*Math.log(pt)-17.49",
        "200_s": "12.626*Math.log(pt)-32.937",
        "600_s": "100-630.75*Math.pow(pt,(-1.0527))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.031",
        "orf_eff": "0.20",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.017",
        "p_max": "64",
        "r_min_b": "0.035",
        "r_max_b": "0.253",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-136.62*Math.log(pt_b)+895.69",
        "141_b": "6.5086*Math.log(pt_b)-17.49",
        "200_b": "12.626*Math.log(pt_b)-32.937",
        "600_b": "100-630.75*Math.pow(pt_b,(-1.0527))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "DR110-025",
        "part_no": "40286-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate": "0.25",
        "pre_orf": "R025",
        "pre-orf_no": "40285-025",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.040",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.198",
        "r_max": "0.354",
        "vmd_s": "-124.75*Math.log(pt)+857.83",
        "141_s": "5.8237*Math.log(pt)-14.979",
        "200_s": "11.308*Math.log(pt)-28.202",
        "600_s": "100-1395.2*Math.pow(pt,(-1.248))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.039",
        "orf_eff": "0.25",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.026",
        "p_max": "63",
        "r_min_b": "0.044",
        "r_max_b": "0.315",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-124.75*Math.log(pt_b)+857.83",
        "141_b": "5.8237*Math.log(pt_b)-14.979",
        "200_b": "11.308*Math.log(pt_b)-28.202",
        "600_b": "100-1395.2*Math.pow(pt_b,(-1.248))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "DR110-03",
        "part_no": "40286-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate": "0.3",
        "pre_orf": "R03",
        "pre-orf_no": "40285-03",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.047",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.237",
        "r_max": "0.424",
        "vmd_s": "-127.27*Math.log(pt)+912.09",
        "141_s": "4.2793*Math.log(pt)-11.045",
        "200_s": "8.4398*Math.log(pt)-20.918",
        "600_s": "100-682.84*Math.pow(pt,(-0.9582))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.047",
        "orf_eff": "0.29",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.037",
        "p_max": "63",
        "r_min_b": "0.052",
        "r_max_b": "0.375",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-127.27*Math.log(pt_b)+912.09",
        "141_b": "4.2793*Math.log(pt_b)-11.045",
        "200_b": "8.4398*Math.log(pt_b)-20.918",
        "600_b": "100-682.84*Math.pow(pt_b,(-0.9582))",
        "cat_b": "UC",
        "psi": "41"
    },
    {
        "ang": "110",
        "tip": "DR110-04",
        "part_no": "40286-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate": "0.4",
        "pre_orf": "R04",
        "pre-orf_no": "40285-04",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.063",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.316",
        "r_max": "0.566",
        "vmd_s": "-140.46*Math.log(pt)+987.44",
        "141_s": "3.9103*Math.log(pt)-10.253",
        "200_s": "7.7754*Math.log(pt)-19.615",
        "600_s": "100-588.64*Math.pow(pt,(-0.8624))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.061",
        "orf_eff": "0.39",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.067",
        "p_max": "61",
        "r_min_b": "0.068",
        "r_max_b": "0.494",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-140.46*Math.log(pt_b)+987.44",
        "141_b": "3.9103*Math.log(pt_b)-10.253",
        "200_b": "7.7754*Math.log(pt_b)-19.615",
        "600_b": "100-588.64*Math.pow(pt_b,(-0.8624))",
        "cat_b": "UC",
        "psi": "43"
    },
    {
        "ang": "110",
        "tip": "DR110-05",
        "part_no": "40286-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate": "0.5",
        "pre_orf": "R05",
        "pre-orf_no": "40285-05",
        "screen_no": "50 Mesh (#40250-00)",
        "screen": "50/Red",
        "cv_tip": "0.079",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.395",
        "r_max": "0.707",
        "vmd_s": "-93.568*Math.log(pt)+848.48",
        "141_s": "1.8141*Math.log(pt)-3.9502",
        "200_s": "3.9931*Math.log(pt)-8.3775",
        "600_s": "100-222.43*Math.pow(pt,(-0.5264))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.075",
        "orf_eff": "0.48",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.104",
        "p_max": "59",
        "r_min_b": "0.084",
        "r_max_b": "0.607",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-93.568*Math.log(pt_b)+848.48",
        "141_b": "1.8141*Math.log(pt_b)-3.9502",
        "200_b": "3.9931*Math.log(pt_b)-8.3775",
        "600_b": "100-222.43*Math.pow(pt_b,(-0.5264))",
        "cat_b": "UC",
        "psi": "44"
    },
    {
        "ang": "110",
        "tip": "DR110-06",
        "part_no": "40286-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate": "0.6",
        "pre_orf": "R06",
        "pre-orf_no": "40285-06",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.095",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.474",
        "r_max": "0.849",
        "vmd_s": "-125.29*Math.log(pt)+991.17",
        "141_s": "1.8936*Math.log(pt)-4.5461",
        "200_s": "4.132*Math.log(pt)-9.6535",
        "600_s": "100-294.08*Math.pow(pt,(-0.567))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.088",
        "orf_eff": "0.56",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.150",
        "p_max": "57",
        "r_min_b": "0.099",
        "r_max_b": "0.713",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-125.29*Math.log(pt_b)+991.17",
        "141_b": "1.8936*Math.log(pt_b)-4.5461",
        "200_b": "4.132*Math.log(pt_b)-9.6535",
        "600_b": "100-294.08*Math.pow(pt_b,(-0.567))",
        "cat_b": "UC",
        "psi": "46"
    },
    {
        "ang": "110",
        "tip": "DR110-08",
        "part_no": "40286-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate": "0.8",
        "pre_orf": "R08",
        "pre-orf_no": "40285-08",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.126",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.632",
        "r_max": "1.131",
        "vmd_s": "-156.62*Math.log(pt)+1147.1",
        "141_s": "1.968*Math.log(pt)-3.684",
        "200_s": "4.0798*Math.log(pt)-8.5953",
        "600_s": "100-230.17*Math.pow(pt,(-0.3971))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.112",
        "orf_eff": "0.71",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.266",
        "p_max": "51",
        "r_min_b": "0.126",
        "r_max_b": "0.906",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-156.62*Math.log(pt_b)+1147.1",
        "141_b": "1.968*Math.log(pt_b)-3.684",
        "200_b": "4.0798*Math.log(pt_b)-8.5953",
        "600_b": "100-230.17*Math.pow(pt_b,(-0.3971))",
        "cat_b": "UC",
        "psi": "51"
    },
    {
        "ang": "110",
        "tip": "DR110-10",
        "part_no": "40286-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate": "1",
        "pre_orf": "R010",
        "pre-orf_no": "40285-10",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.158",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.791",
        "r_max": "1.414",
        "vmd_s": "-127.97*Math.log(pt)+1107",
        "141_s": "2.3349*Math.log(pt)-5.3296",
        "200_s": "3.837*Math.log(pt)-8.9716",
        "600_s": "100-155.28*Math.pow(pt,(-0.2433))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.133",
        "orf_eff": "0.84",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.416",
        "p_max": "46",
        "r_min_b": "0.149",
        "r_max_b": "1.071",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-127.97*Math.log(pt_b)+1107",
        "141_b": "2.3349*Math.log(pt_b)-5.3296",
        "200_b": "3.837*Math.log(pt_b)-8.9716",
        "600_b": "100-155.28*Math.pow(pt_b,(-0.2433))",
        "cat_b": "UC",
        "psi": "57"
    },
    {
        "ang": "110",
        "tip": "DR110-125",
        "part_no": "40286-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate": "1.25",
        "pre_orf": "R12.5",
        "pre-orf_no": "40285-125",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.198",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "0.988",
        "r_max": "1.768",
        "vmd_s": "-109.11*Math.log(pt)+1018.4",
        "141_s": "2.1266*Math.log(pt)-3.8655",
        "200_s": "3.0398*Math.log(pt)-4.4915",
        "600_s": "100-142.98*Math.pow(pt,(-0.2302))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.154",
        "orf_eff": "0.97",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.650",
        "p_max": "39",
        "r_min_b": "0.172",
        "r_max_b": "1.240",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-109.11*Math.log(pt_b)+1018.4",
        "141_b": "2.1266*Math.log(pt_b)-3.8655",
        "200_b": "3.0398*Math.log(pt_b)-4.4915",
        "600_b": "100-142.98*Math.pow(pt_b,(-0.2302))",
        "cat_b": "UC",
        "psi": "66"
    },
    {
        "ang": "110",
        "tip": "DR110-15",
        "part_no": "40286-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate": "1.5",
        "pre_orf": "R15",
        "pre-orf_no": "40285-15",
        "screen_no": "Not Required",
        "screen": "None",
        "cv_tip": "0.237",
        "pt": "40",
        "r_nom": "Math.sqrt(pt/40)*tip_rate",
        "r_min": "1.186",
        "r_max": "2.121",
        "vmd_s": "-121.59*Math.log(pt)+1072.9",
        "141_s": "1.212*Math.log(pt)-0.7116",
        "200_s": "4.1475*Math.log(pt)-9.4304",
        "600_s": "100-204.8*Math.pow(pt,(-0.3589))",
        "cat_s": "UC",
        "pg": "40",
        "cv_ac": "0.245",
        "cv_eff": "0.170",
        "orf_eff": "1.08",
        "r_b": "Math.sqrt(pg/40)*orf_eff",
        "pwm_fac": "1.937",
        "p_max": "34",
        "r_min_b": "0.191",
        "r_max_b": "1.374",
        "pt_b": "pg/pwm_fac",
        "vmd_b": "-121.59*Math.log(pt_b)+1072.9",
        "141_b": "1.212*Math.log(pt_b)-0.7116",
        "200_b": "4.1475*Math.log(pt_b)-9.4304",
        "600_b": "100-204.8*Math.pow(pt_b,(-0.3589))",
        "cat_b": "UC",
        "psi": "77"
    }
];

var tips_fertilizer_table = [
    {
        "tip":"R005",
        "part_no":"40285-005",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"0.05",
        "screen_no":"100 Mesh Stainless (#40251-00)",
        "screen":"100/Green",
        "r_min":"0.025",
        "r_max":"0.071",
        "caps":["40432-047","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R0067",
        "part_no":"40285-007",
        "color": "Pink", "csscolor": "tip-pink",
        "tip_rate":"0.067",
        "screen_no":"100 Mesh Stainless (#40251-00)",
        "screen":"100/Green",
        "r_min":"0.034",
        "r_max":"0.095",
        "caps":["40432-047","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R01",
        "part_no":"40285-01",
        "color": "Orange", "csscolor": "tip-orange",
        "tip_rate":"0.1",
        "screen_no":"100 Mesh Stainless (#40251-00)",
        "screen":"100/Green",
        "r_min":"0.050",
        "r_max":"0.141",
        "caps":["40432-047","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R015",
        "part_no":"40285-015",
        "color": "Green", "csscolor": "tip-green",
        "tip_rate":"0.15",
        "screen_no":"100 Mesh Stainless (#40251-00)",
        "screen":"100/Green",
        "r_min":"0.075",
        "r_max":"0.212",
        "caps":["40432-047","40432-086","40433-047","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R02",
        "part_no":"40285-02",
        "color": "Yellow", "csscolor": "tip-yellow",
        "tip_rate":"0.2",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.100",
        "r_max":"0.283",
        "caps":["40432-047","40432-086","40433-047","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R025",
        "part_no":"40285-025",
        "color": "Purple", "csscolor": "tip-purple",
        "tip_rate":"0.25",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.125",
        "r_max":"0.354",
        "caps":["40432-047","40432-086","40433-047","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R03",
        "part_no":"40285-03",
        "color": "Blue", "csscolor": "tip-blue",
        "tip_rate":"0.3",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.150",
        "r_max":"0.424",
        "caps":["40432-047","40432-086","40433-047","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05","40277-05"]
    },
    {
        "tip":"R04",
        "part_no":"40285-04",
        "color": "Red", "csscolor": "tip-red",
        "tip_rate":"0.4",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.200",
        "r_max":"0.566",
        "caps":["40432-047","40432-086","40432-104","40433-047","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R05",
        "part_no":"40285-05",
        "color": "Brown", "csscolor": "tip-brown",
        "tip_rate":"0.5",
        "screen_no":"50 Mesh Slotted Strainer (#40249-00)",
        "screen":"50/Red Slotted",
        "r_min":"0.250",
        "r_max":"0.707",
        "caps":["40432-086","40432-104","40433-067","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R06",
        "part_no":"40285-06",
        "color": "Grey", "csscolor": "tip-grey",
        "tip_rate":"0.6",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.300",
        "r_max":"0.849",
        "caps":["40432-086","40432-104","40433-067","40433-104","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R08",
        "part_no":"40285-08",
        "color": "White", "csscolor": "tip-white",
        "tip_rate":"0.8",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.400",
        "r_max":"1.131",
        "caps":["40432-086","40432-104","40433-067","40433-104","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R10",
        "part_no":"40285-10",
        "color": "Lt Blue", "csscolor": "tip-lt_blue",
        "tip_rate":"1",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.500",
        "r_max":"1.414",
        "caps":["40432-086","40432-104","40433-067","40433-104","40420-05","40422-05","40424-05","40426-05","40435-05","40436-05","40437-05","40273-05","40274-05"]
    },
    {
        "tip":"R125",
        "part_no":"40285-125",
        "color": "Teal", "csscolor": "tip-teal",
        "tip_rate":"1.25",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.625",
        "r_max":"1.768",
        "caps":["40432-104","40433-104","40422-05","40424-05","40426-05","40436-05","40437-05"]
    },
    {
        "tip":"R15",
        "part_no":"40285-15",
        "color": "Lt Green", "csscolor": "tip-lt_green",
        "tip_rate":"1.5",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"0.750",
        "r_max":"2.121",
        "caps":["40432-104","40433-104","40422-05","40424-05","40426-05","40436-05","40437-05"]
    },
    {
        "tip":"R20",
        "part_no":"40285-20",
        "color": "Tan", "csscolor": "tip-tan",
        "tip_rate":"2",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"1.000",
        "r_max":"2.828",
        "caps":["40433-104","40422-05","40424-05","40426-05","40436-05","40437-05"]
    },
    {
        "tip":"R25",
        "part_no":"40285-25",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"2.5",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"1.250",
        "r_max":"3.536",
        "caps":["40433-104","40424-05","40426-05","40437-05"]
    },
    {
        "tip":"R40",
        "part_no":"40285-30",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"3",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"1.500",
        "r_max":"4.243",
        "caps":["40433-104","40424-05","40426-05"]
    },
    {
        "tip":"R40",
        "part_no":"40285-40",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"4",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"2.000",
        "r_max":"5.657",
        "caps":["40426-05"]
    },
    {
        "tip":"R50",
        "part_no":"40285-50",
        "color": "Black", "csscolor": "tip-black",
        "tip_rate":"5",
        "screen_no":"Not Required",
        "screen":"None",
        "r_min":"2.5",
        "r_max":"7.071",
        "caps":["40426-05"]
    }
];

var cap_descriptions = {
    "40420-05" : "1/8\" Hosebarb",
    "40422-05" : "1/4\" Hosebarb",
    "40424-05" : "3/8\" Hosebarb",
    "40426-05" : "1/2\" Hosebarb",
    "40432-047" : "2-hole Fert cap - S",
    "40432-086" : "2-hole Fert cap - M",
    "40432-104" : "2-hole Fert cap -L",
    "40433-047" : "3-hole Fert cap -S",
    "40433-067" : "3-hole Fert cap - M",
    "40433-104" : "3-hole Fert cap -L",
    "40435-05" : "1/4\" Push-in tube",
    "40436-05" : "3/8\" Push-in tube",
    "40437-05" : "5/16\" Push-in tube",
    "40273-05" : "1/4\" NPTF",
    "40274-05" : "1/4\" NPTF - 45°",
    "40277-05" : "1/8\" NPTF"
};

// Initialize unique tip list
var tips = [];
// Initialize extra info in tips
for (var tip = 0; tip < tips_table.length; ++tip) {
    tips.push(tips_table[tip]["tip"].substring(2));
}

tips = tips.sort();
tips = array_unique(tips);

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function vmd_to_css (vmd)
{
    if (vmd < 60)     return 'vmd-extremely_fine';
    if (vmd <= 105)   return 'vmd-very_fine';
    if (vmd <= 235)   return 'vmd-fine';
    if (vmd <= 340)   return 'vmd-medium';
    if (vmd <= 403)   return 'vmd-coarse';
    if (vmd <= 502)   return 'vmd-very_coarse';
    if (vmd <= 665)   return 'vmd-extremely_coarse';
    return 'vmd-ultra_coarse';
}

// function vmd_to_css (vmd)
// {
//     if (vmd < 60)     return "vmd-extremely_fine";
//     if (vmd <= 105)   return "vmd-very_fine";
//     if (vmd <= 235)   return "vmd-fine";
//     if (vmd <= 340)   return "vmd-medium";
//     if (vmd <= 403)   return "vmd-coarse";
//     if (vmd <= 502)   return "vmd-very_coarse";
//     if (vmd <= 665)   return "vmd-extremely_coarse";
//     return "vmd-ultra_coarse";
// }

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function pt_from_vmd (tip, vmd)
{
    var p_min = 20.0;
    var p_max = 70.0;

    var pt_b = 0.0;

    for (var i = 0; i < 20; ++i) {
        pt_b = p_min;
        var vmd_p_min = eval(tip["vmd_b"]);

        pt_b = p_max;
        var vmd_p_max = eval(tip["vmd_b"]);

        pt_b = (p_max + p_min)*0.5;
        var vmd_p_mid = eval(tip["vmd_b"]);

        if ((vmd >= vmd_p_min && vmd <= vmd_p_mid) || (vmd >= vmd_p_mid && vmd <= vmd_p_min) ) {
            p_max = pt_b;
        } else if ( (vmd >= vmd_p_mid && vmd <= vmd_p_max) || (vmd >= vmd_p_max && vmd <= vmd_p_mid) ) {
            p_min = pt_b;
        } else {
            return 0.0;
        }
    }

    // console.log("Look at me: " + tip["tip"] + " should get " + pt_b + "psi");
    // for (var i = 20; i < 200; i+=5) {
    //     pt_b = i;
    //     var vmd_p_max = eval(tip["vmd_b"]);
    //
    //     console.log(pt_b + " " + vmd_p_max);
    // }

    return pt_b;
}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

// A - Application (gal/acre)
// S - Average Sprayer Speed (mph)
// N - Nozzle Spacing (in)
// An - Spray Tip Angle (80 or 110)
// T – Target Droplet Size

function get_standard_tips (A, S, N, An, T)
{

    // Math to figure out calculated rate
    var R = (A * S * N) / 5940.0

    // Copy all of the tips_table into a new array
    var filtered = tips_table.slice();
    var left_over = [];

    //
    // 1. Use spray tip angle to reduce available tips
    //

    filtered = filtered.filter(function (el) {
        return el["ang"] == An;
    });

    //
    // 2. Using calculated rate (R) find tips fit within this range for min and max
    // flows (2 new columns added to spreadsheet)
    //

    filtered = filtered.filter(function (el) {
        return R >= el["r_min"] && R <= el["r_max"];
    });


    if (T) {
        //
        // 3. Using Droplet Size input, compare to calculated VMD (using VMD formula) for
        // all tips above to pick tips within +/-25 of input value.  If not at least 4 tips
        // shown, then increase +/- repeatedly to include more tips.
        //
        // Alternative would be to do a percentage of input value. Say start within +/- 5%
        // and increase by 5 from there
        //

        filtered = filtered.sort(function (ela, elb) {

            var pt = ela["pt"];
            var VMD_a = eval(ela["vmd_s"]);

            var pt = elb["pt"];
            var VMD_b = eval(elb["vmd_s"]);

            var diff_a = Math.abs(T - VMD_a);
            var diff_b = Math.abs(T - VMD_b);

            if (diff_a < diff_b) {
                return -1;
            } else if (diff_a > diff_b) {
                return 1;
            } else {
                return 0;
            }
        });

        // Truncate to 5 items
        left_over = filtered.slice(5);
        filtered = filtered.slice(0,5);


    } else {
        //
        // 4. If no droplet size is inputted, then show all tips
        //

        // Do nothing, array of tips stays the same
    }

    // 5. Sorting
    filtered = sort_tips(filtered);
    left_over = sort_tips(left_over);

    return [filtered, left_over];
}

// A - Application (gal/acre)
// S - Average Sprayer Speed (mph)
// N - Nozzle Spacing (in)
// An - Spray Tip Angle (80 or 110)
// T – Target Droplet Size

function get_pulsed_tips (A, S, N, An, T, speed_conv)
{

    // Math to figure out calculated rate
    var R = (A * S * N) / 5940.0

    // Copy all of the tips_table into a new array
    var filtered = tips_table.slice();
    var left_over = [];

    //
    // 1. Use spray tip angle to reduce available tips
    //

    filtered = filtered.filter(function (el) {
        return el["ang"] == An;
    });

    //
    // 2. Using calculated rate (R) find tips that fit within this range for min and max
    // flows for blended pulse (2 new columns added to spreadsheet)
    //

    filtered = filtered.filter(function (el) {
        return R >= el["r_min_b"] && R <= el["r_max_b"];
    });

    if (T) {

        //
        // Speed Fix
        //

        filtered = filtered.filter(function (el) {

            var pg = pt_from_vmd (el, T);
            if (pg == 0.0)
                return false;

            var orf_eff = eval(el["orf_eff"]);
            var R2 = Math.sqrt(pg/el["pt"]) * orf_eff;

            var Smax = (R2 * 5940)/(A*N);
            var speed_max = Smax*speed_conv;

            console.log(el["tip"] + ' = ' + speed_max + " S=" + S + " (" + speed_max*0.4 + " - " + speed_max*1.1 + ")");

            return S >= (speed_max*0.4) && S <= (speed_max*1.1);
        });

        //
        // 3. Using Droplet Size input, compare to calculated VMD (using VMD formula) for
        // all tips above to pick tips within +/-25 of input value.  If not at least 4 tips
        // shown, then increase +/- repeatedly to include more tips.
        //
        // Alternative would be to do a percentage of input value. Say start within +/- 5%
        // and increase by 5 from there
        //

        filtered = filtered.sort(function (ela, elb) {
            var pwm_fac = ela["pwm_fac"];
            var pg = ela["pg"];
            var pt_b = eval(ela["pt_b"]);
            var VMD_a = eval(ela["vmd_b"]);

            var pwm_fac = elb["pwm_fac"];
            var pg = elb["pg"];
            var pt_b = eval(elb["pt_b"]);
            var VMD_b = eval(elb["vmd_b"]);

            var diff_a = Math.abs(T - VMD_a);
            var diff_b = Math.abs(T - VMD_b);

            if (diff_a < diff_b) {
                return -1;
            } else if (diff_a > diff_b) {
                return 1;
            } else {
                return 0;
            }
        });

        // Truncate to 6 items
        filtered = filtered.slice(0,8);


    } else {
        //
        // 4. If no droplet size is inputted, then show all tips
        //

        // Do nothing, array of tips stays the same
    }

    // 5. Sorting
    filtered = sort_tips(filtered);

    return [filtered, left_over];
}

function get_specific_tips (N)
{

    // Copy all of the tips_table into a new array
    var filtered = tips_table.slice();
    var left_over = [];

    filtered = filtered.filter(function (el) {
        return el["tip"].substring(2) == N;
    });

    filtered = sort_tips(filtered);
    left_over = sort_tips(left_over);

    return [filtered, left_over];
}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function build_charts_standard (tips, A, S, N, speed_conv, press_conv, press_decimals)
{

    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (size == "ER") {
            min_pressure = 20;
            max_pressure = 100;
        } else {
            min_pressure = 25;
            max_pressure = 100;
        }

        // For each pressure
        for (var pt = min_pressure; pt <= max_pressure; pt += 5) {

            var R2 = Math.sqrt(pt/tips[r]["pt"]) * tips[r]["tip_rate"];
            var SS = (R2 * 5940)/(A*N);

            var chart = {};
            chart.speed = format_number(SS*speed_conv);
            chart.pressure = (pt*press_conv).toFixed(press_decimals);
            chart.vmd = Math.round(eval(tips[r]["vmd_s"]));
            chart.lt141 = Math.round(eval(tips[r]["141_s"]));
            chart.lt200 = Math.round(eval(tips[r]["200_s"]));
            chart.lt600 = Math.round(eval(tips[r]["600_s"]));
            chart.highlight = false;
            chart.csscolor = tips[r].csscolor;

            tips[r].chart.push(chart);
        }

        // Calculate target
        var R = (A * S * N) / 5940.0
        var pt = tips[r]["pt"] * Math.pow(R/tips[r]["tip_rate"], 2.0);
        var R2 = Math.sqrt(pt/tips[r]["pt"]) * tips[r]["tip_rate"];
        var S = (R2 * 5940)/(A*N);

        var chart = {};
        chart.speed = format_number(S*speed_conv);
        chart.pressure = (pt*press_conv).toFixed(press_decimals);
        chart.vmd = Math.round(eval(tips[r]["vmd_s"]));
        chart.lt141 = Math.round(eval(tips[r]["141_s"]));
        chart.lt200 = Math.round(eval(tips[r]["200_s"]));
        chart.lt600 = Math.round(eval(tips[r]["600_s"]));
        chart.highlight = true;
        chart.csscolor = tips[r].csscolor;

        tips[r].chart.push(chart);

        // Sort final results
        tips[r].chart = tips[r].chart.sort(function (ela, elb) {
            if (parseFloat(ela.pressure) < parseFloat(elb.pressure)) {
                return -1;
            } else if (parseFloat(ela.pressure) > parseFloat(elb.pressure)) {
                return 1;
            } else {
                return 0;
            }
        });
    }
}

function build_charts_pulsed (tips, A, S, N, T, speed_conv, press_conv, press_decimals)
{

    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (size == "ER") {
            min_pressure = 20;
            max_pressure = 65;
        } else {
            min_pressure = 25;
            max_pressure = 65;
        }

        for (var pg = min_pressure; pg <= max_pressure; pg += 5) {

            var orf_eff = eval(tips[r]["orf_eff"]);
            //var r_b = eval(tips[r]["r_b"]);

            var R2max = Math.sqrt(pg/40)*orf_eff;
            var Smax = (R2max * 5940)/(A*N);

            //var R2min = Math.sqrt(pg/tips[r]["pt"]) * tips[r]["r_min_b"];
            var Smin = Smax * 0.25; //(R2min * 5940)/(A*N);

            var chart = {};
            chart.speed_max = format_number(Smax*speed_conv); //S;
            chart.speed_min = format_number(Smin*speed_conv); //S;
            chart.duty = Math.round((S*speed_conv/chart.speed_max)*100.0);
            if (chart.duty > 100) {
                chart.duty = ">100";
            }

            chart.pressure = (pg*press_conv).toFixed(press_decimals);

            var pwm_fac = tips[r]["pwm_fac"];
            var pt_b = eval(tips[r]["pt_b"]);

            chart.vmd = Math.round(eval(tips[r]["vmd_b"]));
            chart.lt141 = Math.round(eval(tips[r]["141_b"]));
            chart.lt200 = Math.round(eval(tips[r]["200_b"]));
            chart.lt600 = Math.round(eval(tips[r]["600_b"]));
            chart.csscolor = tips[r].csscolor;

            chart.highlight = false;

            tips[r].chart.push(chart);
        }

        // For each calculated result, find the closest vmd and highlight it
        var closest_vmd = 0;

        for (var i = 1; i < tips[r].chart.length; ++i) {
            if (Math.abs(tips[r].chart[i].vmd - T) < Math.abs(tips[r].chart[closest_vmd].vmd - T)) {
                closest_vmd = i;
            }
        }

        tips[r].chart[closest_vmd].highlight = true;

    }
}

function build_charts_specific_standard (tips, A, S, N, speed_conv, press_conv, rate_conv, press_decimals)
{

    // Calculate with constant speed
    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart_rate = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (size == "ER") {
            min_pressure = 20;
            max_pressure = 100;
        } else {
            min_pressure = 25;
            max_pressure = 100;
        }

        // For each pressure
        for (var pt = min_pressure; pt <= max_pressure; pt += 5) {
            //var S = (R * 5940)/(A*N)

            var R2 = Math.sqrt(pt/tips[r]["pt"]) * tips[r]["tip_rate"];
            var SS = (R2 * 5940)/(A*N);

            var chart = {};
            chart.speed = format_number(SS*speed_conv);
            chart.pressure = (pt*press_conv).toFixed(press_decimals);
            chart.application_rate = (A*rate_conv).toFixed(1);
            chart.vmd = Math.round(eval(tips[r]["vmd_s"]));
            chart.lt141 = Math.round(eval(tips[r]["141_s"]));
            chart.lt200 = Math.round(eval(tips[r]["200_s"]));
            chart.lt600 = Math.round(eval(tips[r]["600_s"]));
            chart.csscolor = tips[r].csscolor;

            tips[r].chart_rate.push(chart);
        }

    }

    // Calculate with constant application rate
    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart_speed = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (size == "ER") {
            min_pressure = 20;
            max_pressure = 100;
        } else {
            min_pressure = 25;
            max_pressure = 100;
        }

        // For each pressure
        for (var pt = min_pressure; pt <= max_pressure; pt += 5) {
            //var S = (R * 5940)/(A*N)

            var A40 = tips[r]["tip_rate"]*5940/(S*N);
            var A2 = A40 * Math.sqrt(pt/tips[r]["pt"]);

            var chart = {};
            chart.speed = format_number(S*speed_conv);
            chart.pressure = (pt*press_conv).toFixed(press_decimals);
            chart.application_rate = (A2*rate_conv).toFixed(1);
            chart.vmd = Math.round(eval(tips[r]["vmd_s"]));
            chart.lt141 = Math.round(eval(tips[r]["141_s"]));
            chart.lt200 = Math.round(eval(tips[r]["200_s"]));
            chart.lt600 = Math.round(eval(tips[r]["600_s"]));
            chart.csscolor = tips[r].csscolor;

            tips[r].chart_speed.push(chart);
        }

    }


    // Combine chart
    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart_combined = [];

        for (var i = 0; i < tips[r].chart_speed.length; ++i) {
            var chart = {};

            chart.speed_cs = tips[r].chart_speed[i].speed;
            chart.application_rate_cs = tips[r].chart_speed[i].application_rate;

            chart.speed_cr = tips[r].chart_rate[i].speed;
            chart.application_rate_cr = tips[r].chart_rate[i].application_rate;

            chart.pressure = tips[r].chart_speed[i].pressure;
            chart.vmd = tips[r].chart_speed[i].vmd;
            chart.lt141 = tips[r].chart_speed[i].lt141;
            chart.lt200 = tips[r].chart_speed[i].lt200;
            chart.lt600 = tips[r].chart_speed[i].lt600;
            chart.csscolor = tips[r].csscolor;

            tips[r].chart_combined.push(chart);
        }
    }
}

function build_charts_specific_pulsed (tips, A1, A2, N, speed_conv, press_conv, press_decimals)
{

    // Calculate with constant speed
    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart_rate = [];

        // Get style and size
        var style = tips[r]["tip"].substring(0,2);
        var size = tips[r]["tip"].substring(2);

        var min_pressure = 0;
        var max_pressure = 0;

        if (size == "ER") {
            min_pressure = 20;
            max_pressure = 65;
        } else {
            min_pressure = 25;
            max_pressure = 65;
        }

        // For each pressure
        for (var pg = min_pressure; pg <= max_pressure; pg += 5) {

            var orf_eff = eval(tips[r]["orf_eff"]);
            //var r_b = eval(tips[r]["r_b"]);

            var R2max = Math.sqrt(pg/40)*orf_eff
            var S1_100 = (R2max * 5940)/(A1*N);
            var S1_25 = S1_100 * 0.25; //(R2min * 5940)/(A1*N);
            var S1_50 = S1_100 * 0.50; //(R2min * 5940)/(A1*N);
            var S1_75 = S1_100 * 0.75; //(R2min * 5940)/(A1*N);

            var R2max = Math.sqrt(pg/40)*orf_eff
            var S2_100 = (R2max * 5940)/(A2*N);
            var S2_25 = S2_100 * 0.25; //(R2min * 5940)/(A1*N);
            var S2_50 = S2_100 * 0.50; //(R2min * 5940)/(A1*N);
            var S2_75 = S2_100 * 0.75; //(R2min * 5940)/(A1*N);

            var chart = {};
            chart.speed_25_1 = format_number(S1_25 * speed_conv);
            chart.speed_50_1 = format_number(S1_50 * speed_conv);
            chart.speed_75_1 = format_number(S1_75 * speed_conv);
            chart.speed_100_1 = format_number(S1_100 * speed_conv);

            chart.speed_25_2 = format_number(S2_25 * speed_conv);
            chart.speed_50_2 = format_number(S2_50 * speed_conv);
            chart.speed_75_2 = format_number(S2_75 * speed_conv);
            chart.speed_100_2 = format_number(S2_100 * speed_conv);

            chart.pressure = (pg*press_conv).toFixed(press_decimals);

            var pwm_fac = tips[r]["pwm_fac"];
            var pt_b = eval(tips[r]["pt_b"]);

            chart.vmd = Math.round(eval(tips[r]["vmd_b"]));
            chart.lt141 = Math.round(eval(tips[r]["141_b"]));
            chart.lt200 = Math.round(eval(tips[r]["200_b"]));
            chart.lt600 = Math.round(eval(tips[r]["600_b"]));
            chart.csscolor = tips[r].csscolor;

            tips[r].chart_rate.push(chart);
        }

    }

}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------

function get_fertilizer_tips (AA, AB, S, N, C)
{
    var gpm_a = (AA * S * N) / 5940.0 * C;
    var gpm_b = (AB * S * N) / 5940.0 * C;

    var RA = (AA*S*N)/5940.0*C;
    var RB = (AB*S*N)/5940.0*C;

    // Copy all of the tips_table into a new array
    var filtered = tips_fertilizer_table.slice();

    //
    // 1. Using calculated rate (RA) find pre-orifice within this range for min
    // and max flows (2 columns in spreadsheet).
    //

    filtered = filtered.filter(function (el) {
        return RA >= el["r_min"] && RA <= el["r_max"];
    });

    // 2. Sorting
    filtered = sort_fertilizer_tips(filtered);

    return filtered;
}

function build_charts_fertilizer (tips, AA, AB, S, N, C, speed_conv, press_conv, press_decimals)
{

    for (var r = 0; r < tips.length; ++r) {

        // Empty the current chart
        tips[r].chart = [];

        for (var pt = 10; pt <= 80; pt += 5) {

            var chart = {};
            chart.pressure = (pt*press_conv).toFixed(press_decimals);

            var RA = Math.sqrt(pt/40.0) * tips[r]["tip_rate"];
            var SA = (RA * 5940)/(AA*N*C);
            chart.speed_a = format_number(SA*speed_conv);

            if (AB > 0.0) {
                var RB = Math.sqrt(pt/40.0) * tips[r]["tip_rate"];
                var SB = (RA * 5940)/(AB*N*C);
                chart.speed_b = format_number(SB*speed_conv);
            } else {
                chart.speed_b = "-";
            }

            chart.highlight_1 = false;
            chart.highlight_2 = false;
            chart.csscolor = tips[r].csscolor;

            tips[r].chart.push(chart);
        }

        // var R = (A * S * N) / 5940.0
        // var pt = tips[r]["pt"] * Math.pow(R/tips[r]["tip_rate"], 2.0);
        // var R2 = Math.sqrt(pt/tips[r]["pt"]) * tips[r]["tip_rate"];
        // var S = (R2 * 5940)/(A*N);
        //

        // Calculate target
        var RA = (AA * S * N * C) / 5940.0;
        var SA = S;
        var SB = (RA * 5940)/(AB*N*C);
        var pta = 40.0 * Math.pow(RA/tips[r]["tip_rate"], 2.0);

        var chart = {};
        chart.pressure = (pta*press_conv).toFixed(press_decimals);
        chart.speed_a = format_number(SA*speed_conv);

        if (AB > 0.0) {
            chart.speed_b = format_number(SB*speed_conv);
        } else {
            chart.speed_b = "-";
        }
        chart.highlight_1 = true;
        chart.csscolor = tips[r].csscolor;

        tips[r].chart.push(chart);


        if (AB > 0.0) {
            var RB = (AB * S * N * C) / 5940.0;
            var SA = (RB * 5940)/(AA*N*C);
            var SB = S;
            var ptb = 40.0 * Math.pow(RB/tips[r]["tip_rate"], 2.0);

            var chart = {};
            chart.pressure = (ptb*press_conv).toFixed(press_decimals);
            chart.speed_a = format_number(SA*speed_conv);

            chart.speed_b = format_number(SB*speed_conv);

            chart.highlight_2 = true;
            chart.csscolor = tips[r].csscolor;

            tips[r].chart.push(chart);
        }

        // Sort final results
        tips[r].chart = tips[r].chart.sort(function (ela, elb) {
            if (parseFloat(ela.pressure) < parseFloat(elb.pressure)) {
                return -1;
            } else if (parseFloat(ela.pressure) > parseFloat(elb.pressure)) {
                return 1;
            } else {
                return 0;
            }
        });

        // Descriptions
        tips[r].cap_descriptions = [];
        for (var cap = 0; cap < tips[r].caps.length; ++cap) {
            d = {
                "name": tips[r].caps[cap],
                "descrp": cap_descriptions[tips[r].caps[cap]]
            };
            tips[r].cap_descriptions.push(d);
        }

    }


}

//----------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------
